SystemOrganization addCategory: #ScriptLoader12!

Object subclass: #Loader
	instanceVariableNames: ''
	classVariableNames: 'PackagesBeforeLastLoad'
	poolDictionaries: ''
	category: 'ScriptLoader12'!

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
packageToBeTestedFolderName

	^ 'packages-to-be-tested'! !

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
waitingCacheFolder
	^ (FileDirectory default directoryNamed: self packageToBeTestedFolderName)
		assureExistence;
		yourself

	! !

!Loader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2010 17:41'!
allCurrentVersions
	"self new allCurrentVersions"
	
	| copies names |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	names := copies collect:
		[:ea |  ea ancestry ancestorString ].
	^ names reject: #isEmpty! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:51'!
currentChangedPackages
	"self new currentChangedPackages" 
	
	^  self currentPackages select: [:each |
		each needsSaving or: [
			(PackagesBeforeLastLoad includes: each ancestry ancestorString) not ] ]! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumber

	^ self class currentMajorVersionNumber ! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumberWithoutDot
	"self new currentMajorVersionNumberWithoutDot"
	^ self class currentMajorVersionNumber asString copyWithout: $.! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:42'!
currentVersionsToBeSaved
	"self new currentVersionsToBeSaved"
	
	^ self allCurrentVersions reject: [ :each |
		self packagesNotToSavePatternNames
			anySatisfy: [ :p | p match: each ] ]! !

!Loader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 9/10/2010 17:51'!
diffPackages
	"return a list of packages that are new. They can be dirty or not."
	"self new diffPackages"
	 
	| diff |
	diff := Set new.
	self currentVersionsToBeSaved do: [:each |
		(PackagesBeforeLastLoad includes: each) ifFalse: [diff add: each]].
	^ diff
	! !

!Loader methodsFor: 'initialize' stamp: 'StephaneDucasse 9/10/2010 17:49'!
initialize
	super initialize.
	PackagesBeforeLastLoad ifNil: [ PackagesBeforeLastLoad := Set new ]! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
markPackagesBeforeNewCodeIsLoaded
	"Use this method to keep a log of all the packages that were loaded before loading new code. This will help the system to perform a diff and know after what to publish."
	
	"self new markPackagesBeforeNewCodeIsLoaded"
	
	PackagesBeforeLastLoad := self currentVersionsToBeSaved! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:40'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
		).! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
resetPackagesBeforeLastLoad
	PackagesBeforeLastLoad := Set new! !

Loader subclass: #ScriptLoader
	instanceVariableNames: 'repository inboxRepository repository39 repositorySqueakTrunk repository310 repositoryTaskForces repositoryMC repositoryTreated'
	classVariableNames: 'CheckImageInSyncWithUpdate CurrentMajorVersionNumber CurrentScriptVersionNumber CurrentUpdateVersionNumber CurrentlyIntegratingChanges LogStream Repository'
	poolDictionaries: ''
	category: 'ScriptLoader12'!

!ScriptLoader commentStamp: 'StephaneDucasse 5/26/2010 20:49' prior: 0!
Pharo Process Description


---
Here is the pharo process.

General points
-----------------------
An enhancement
	- should be added to the bug tracker
	- announced to the mailing-list
	- asked for feedback 
	- results should be added to the BT entry

Fixed tag means ready for integration
Closed tag means integrated

A bug detected
	- discuss via the mailing-list
	- should be added to the bug tracker
	- fix are considered as enh (see point above)

When a fix is fixed it should be either post as cs to the BT entry or in the PharoInbox
as a Slice (a slice is an emtpy package that has as requirement other package composing the fix).

We have three projects:
	Pharo
	PharoInbox
	PharoTreatedInbox

A fix goes either from inbox to treatedInbox or to Pharo.
If a fix does not work it is moved to the TreatedInbox.
If a fix works it is integrated as follow - it will be moved from the Inbox to the TreatedInbox
and integrated and published in the Pharo project

To help browsing multiple repositories:

ScriptLoader new addExtraRepositories


+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Now the integration works in 4 main steps which can be steered by the following expression
ScriptLoader releaseMenu
or via the menu that can be shown/hidden using 
	ScriptLoader showIntegrationMenu
	ScriptLoader hideIntegrationMenu


1.) Start up a recent and clean image
	ScriptLoader new prepareNewUpdate
	
	This step will 
		- load the latest updates
		- load the latest ScriptLoader package from the Pharo repository.
		Indeed when we work on improving the ScriptLoader it may not be published in the update stream. 
		New versions can be available on the server but not part of the latest updates.
		Therefore the process always loads the latest version of scriptloader from the pharo repository.
		This point is important because when an integration failed, you have to check and optionally 
		remove the scriptloader package from the pharo repository.
		
		- check that the update.list (which contains the cs to load the packages) is in sync
		with the image current version. You have to download the latest version using a script like this one.
		Pay attention to update it so that it reflects the right version (ie 1.0, 1.1, 1.2...)
		     scp -p LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/updates.list .
		- snapshot the package version to detect dirty or changed but non dirty packages.

2.) Apply changes

	ScriptLoader new doneApplyingChanges
	
	This step will 
		- create an update method with can trigger the load of the packages and some pre/post actions
		- create a script method with describes all the package versions and it used by the update methods
		- save all the packages that are different (except some filtered packages)	
		into a local folder named package-to-be-tested.
		ScriptLoader, SLICE*.... and a couple of other packages are not considered to be included in the script method
			(check method packagesNotToSavePatternNames)
		

3.) Verify changes
	==> in a ***new*** image (in the current folder) execute:
	ScriptLoader new verifyNewUpdate

	This step will 
		- load in any order (so may break) the package previously saved
		in the packages to be tested.
		- this step is important because you may get simple changes with unexpected side effects and that 
		may break the load.
		

4.) If there are problems go to 2.) to fix them, else:
	ScriptLoader new publishChanges

	This step will
		- generate a new cs file whose purpose is to load the given version of the scriptloader and trigger the 
		correct update method.
		- add the name of the cs file to the end of the updates.list file local to the disc
		- copy all the package from the local directory to the Pharo
		
	After the updates.list and the cs file should be manually uploaded to the ftp (see below) 
	   scp "$1" LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/
	

5) in case of problems.
Think that if you pass the step 4 you may have a scriptLoader version that got published and that is reloaded 
during the first step.



CurrentMajorVersionNumber should contains a string '1.0', '1.1'....
This string will determine on which folder on the server the updates.list should be loaded.
	i.e., updates/pharo1.0, updates/pharo1.1 ....

--- Not to forget ---
To change the release stream
add a new method for each releaseStream
	ScriptLoader toPharoOne
	ScriptLoader toPharoOneDotOne
!

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 9/10/2010 17:28'!
checkImageInSyncWithUpdate
	"most of the time you want to make sure that your image is in sync with the latest item of the update.list
	but in some cases you do not to get forced to have this behavior."
	
	^ CheckImageInSyncWithUpdate ifNil: [CheckImageInSyncWithUpdate := true]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 6/12/2010 08:47'!
checkImageInSyncWithUpdate: aBoolean

	CheckImageInSyncWithUpdate := aBoolean! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:15'!
currentMajorVersionNumber

	^ CurrentMajorVersionNumber ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:12'!
currentMajorVersionNumber: aNumber

	CurrentMajorVersionNumber := aNumber! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:06'!
currentlyIntegratingChanges

	CurrentlyIntegratingChanges isNil ifTrue: [self hideIntegrationMenu].
	^ CurrentlyIntegratingChanges! !

!ScriptLoader class methodsFor: 'private' stamp: 'adrian_lienhard 3/16/2009 21:32'!
defaultMCWaitingFolder
	"self defaultMCWaitingFolder" 
	
	^ MCDirectoryRepository new directory: self waitingCacheFolder! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			(self new)
				installGofer;
				gofer ]! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
hideIntegrationMenu

	CurrentlyIntegratingChanges := false.! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'StephaneDucasse 9/10/2010 17:24'!
initialize
	self flag: #shouldRemoveNumber.
	CurrentMajorVersionNumber :=  1.2! !

!ScriptLoader class methodsFor: 'private' stamp: 'al 11/1/2008 20:03'!
loadLatestPackage: aString from: aPath
	| repository |
	
	repository := MCHttpRepository
		location: aPath
		user:  ''
		password: ''.
	self loadLatestPackage: aString fromRepository: repository! !

!ScriptLoader class methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
loadLatestPackage: aString fromRepository: aRepository
	| versionsBlock versions tries |
	
	versionsBlock := [ (aRepository allVersionNames select: [ :each |
		each beginsWith: aString ])
		asSortedCollection: [ :a :b |
			(a copyAfterLast: $.) asNumber <= (b copyAfterLast: $.) asNumber]].
	versions := versionsBlock value.
	tries := 0.
	[ versions isEmpty and: [ tries < 3 ] ] whileTrue: [
		versions := versionsBlock value.
		tries := tries + 1 ].
	versions isEmpty ifTrue: [ self error: 'problems when accessing squeaksource' ].
	
	aRepository versionReaderForFileNamed: (versions last , '.mcz') do: [:reader | | version |
		version := reader version.
		version load.
		version workingCopy repositoryGroup addRepository: aRepository]! !

!ScriptLoader class methodsFor: 'private' stamp: 'AlexandreBergel 10/23/2008 15:31'!
loadLatestPackage: aString fromSqueaksource: aDirectoryName
	" self loadLatestPackage: 'ScriptLoader' fromSqueaksource: 'Pharo' "

	self loadLatestPackage: aString from: 'http://www.squeaksource.com/', aDirectoryName
	! !

!ScriptLoader class methodsFor: 'menu' stamp: 'AlainPlantec 10/19/2010 22:47'!
menuCommandOn: aBuilder 
	<worldMenu> 
	
	(aBuilder item: #'Integrator Menu')
		order: 1.5;
		precondition: [self currentlyIntegratingChanges];
		parent: #System;
		icon: UITheme current smallAuthoringToolsIcon;
		action: [ScriptLoader releaseMenu]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 11/9/2010 18:39'!
releaseMenu
	"self releaseMenu"
	|symbol|
	symbol := UIManager default
		chooseFrom: #('1- Prepare new update'
		                        '2- Save new image for testing (optional)'
						'3- Freeze changes: packages will be saved (required)'
						'4- Verify new update (open the mother image in the same folder) (optional)'
						'5- Publish changes')
		values: #(prepareNewUpdate saveImageForRunningTests doneApplyingChanges verifyNewUpdate publishChanges).
	symbol ifNotNil: [ScriptLoader new perform: symbol]! !

!ScriptLoader class methodsFor: 'public' stamp: 'adrian-lienhard 6/6/2009 11:46'!
resetLogStream
	LogStream := nil! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
showIntegrationMenu

	CurrentlyIntegratingChanges := true.! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOne

	self currentMajorVersionNumber: 1.0! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOneDotOne

	self currentMajorVersionNumber: 1.1! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 5/14/2010 22:21'!
toPharoOneDotTwo

	self currentMajorVersionNumber: 1.2! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 2/25/2010 18:22'!
CSForLastUpdate: aString
	"ScriptLoader new CSForLastUpdate: 'cleanUpMethods'"
	
	| str updateNumber filename|
	updateNumber := self getLatestUpdateNumber.
	filename := updateNumber asString, '-Pha-', aString, '.cs'.
	FileDirectory default 
		forceNewFileNamed:  filename
		do: [ :stream | 
					self 
						generateCS: self latestScriptLoaderPackageIdentificationString
						fromUpdate: updateNumber on: stream].
	^ filename! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2010 22:31'!
CSForLastUpdateAndPatchUpdatesList: aString
	"ScriptLoader new CSForLastUpdateAndPatchUpdatesList: 'cleanUpMethods'"
	| filename |
	filename := self CSForLastUpdate: aString.
	self updateUpdatesList: aString.
	^ filename ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addExtraRepositories
	
	"self new addExtraRepositories"
	
	self addRepository39ToAllPackages.
	self addRepository310ToAllPackages.
	self addRepositoryTaskForcesToAllPackages.
	self addRepositorySqueakTrunkToAllPackages.
	self addRepositoryMCToAllPackages.
	self addRepositoryTreatedToAllPackages.! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 21:51'!
addHomeRepositoryToAllPackages
	"self new addHomeRepositoryToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			addRepository: self repositoryTreated ].
		
	MCRepositoryGroup default
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			 addRepository: self repositoryTreated.
	
		
	
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 17:40'!
addHomeRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 10/18/2009 16:11'!
addPackage: aString
	"to be tested" 
	
	| workingCopy |
	PackageInfo registerPackageName: aString.
	workingCopy := MCWorkingCopy forPackage: (MCPackage new name: aString)! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/13/2009 15:48'!
addRepository310ToAllPackages
	"self new addRepository310ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository310
			].
	
	! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/6/2009 17:38'!
addRepository39ToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepository39ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository39
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/14/2009 10:31'!
addRepositoryMCToAllPackages
	
	"self new addRepositoryMCToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryMC
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2009 20:47'!
addRepositorySqueakTrunkToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepositorySqueakTrunkToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositorySqueakTrunk
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/13/2009 15:59'!
addRepositoryTaskForcesToAllPackages
	"self new addRepositoryTaskForcesToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTaskForces
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 10/31/2005 18:01'!
addRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addRepositoryTreatedToAllPackages
	"self new addRepositoryTreatedToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTreated
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentDirtyPackages
	"ScriptLoader new allCurrentDirtyPackages"
	"return all the current dirty packages even the ones that we do not want to save"

	
	^  self allCurrentPackages select: [:each | each needsSaving].

	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentPackages
	"ScriptLoader new allCurrentPackages" 
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:26'!
announceOnMailingList
	"
	self new announceOnMailingList"
	|title|
	title := '[update ', self currentMajorVersionNumber asString , '] #', self currentUpdateVersionNumber asString.
UIManager default
	edit: title, String cr, self currentUpdateVersionNumber asString, '
-----

', self commentForCurrentUpdate
	label: title.! !

!ScriptLoader methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
buildConfigurationMapFor: packageNames

	| configurationMap |
	configurationMap := MCConfiguration new.
	configurationMap repositories
		add: self repository;
		add: self inboxRepository.

	packageNames do: [:packageName | | version depArray |
		version := self loadVersionFromFileNamed: packageName.
		depArray := { version package name. version info name. version info id asString. }.
		configurationMap dependencies add: (MCConfiguration dependencyFromArray: depArray)].
	^configurationMap! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 7/7/2010 23:32'!
checkImageIsUptodate

	| stream last number |
	self class checkImageInSyncWithUpdate 
		ifFalse: [^ true].	
	stream := FileDirectory default oldFileNamed: 'updates.list'.
	stream contents linesDo: [ :each | last := each ].
	stream close.
	last isNil 
		ifTrue: [^ false]. "in case the file is empty"
	 (last copyUpTo: $-) isAllDigits
		ifFalse: [^ true].  			"for cases where we have #Pharo1.1rc1 starting the line"
	number := (last copyUpTo: $-) asNumber.
	^ number = self getLatestUpdateNumber ! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 11/13/2010 22:31'!
cleanRepositories
	"self new cleanRepositories"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllRepositories.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 6/7/2010 11:11'!
cleanUpForProduction
	"self new cleanUpForProduction"
	
	| oldDicts newDicts |
	
	"trim MC ancestory information"
	MCVersionInfo allInstances do: [ :each | each instVarNamed: 'ancestors' put: nil ].	

	"delete logo"	
	LogoImageMorph default: nil.

	"delete ScriptLoader log"
	ScriptLoader resetLogStream.

	(MCPackage named: 'HelpSystem') unload.
	Smalltalk globals at: #SUnitUnloader ifPresent:[ :unloader | unloader new unloadAll  ].

	"shrink method dictionaries."
	Smalltalk garbageCollect.
	oldDicts := MethodDictionary allInstances.
	newDicts := Array new: oldDicts size.
	oldDicts withIndexDo: [ :d :index | newDicts at: index put: d rehashWithoutBecome ].
	oldDicts elementsExchangeIdentityWith: newDicts.
	oldDicts := newDicts := nil.
	
	self removeDejaVuFonts.
	(MCPackage named: 'GraphicsResources') unload.
	
	(MCPackage named: 'HostMenus') unload.
	
	self cleanUpForRelease.
	(MCPackage named: self theScriptLoaderPackageName) unload.
	Smalltalk garbageCollect
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AlainPlantec 9/23/2010 10:30'!
cleanUpForRelease
	"self new cleanUpForRelease"

	Author fullName: 'Mr.Cleaner'.
	DebuggerMethodMap withAllSubclassesDo: [ :each | each voidMapCache ].
	self cleanUpPackageOrganizer.
	self cleanUpMethods.
	DataStream initialize.
	Smalltalk cleanUpUndoCommands.
	GradientFillStyle initPixelRampCache.
	FreeTypeCache clearCurrent.
	ImageMorph classPool at: #DefaultForm put: (Form extent: 1 @ 1 depth: 1).
	Behavior flushObsoleteSubclasses.
	CommandHistory resetAllHistory.
	CommandHistory allInstancesDo: #initialize.
	MethodChangeRecord allInstancesDo: [ :x | x noteNewMethod: nil ].
	World cleanseOtherworldlySteppers.
	Smalltalk organization removeEmptyCategories.
	Browser initialize.
	SystemBrowser removeObsolete.
	AppRegistry removeObsolete.
	FileServices removeObsolete.
	MCFileBasedRepository flushAllCaches.
	MCMethodDefinition shutDown. 
	MCDefinition clearInstances.
	Smalltalk globals
		at: #TTFontDescription
		ifPresent: [ :c | 
			c
				clearDefault;
				clearDescriptions ].
	ExternalDropHandler resetRegisteredHandlers.
	Undeclared removeUnreferencedKeys.
	Smalltalk globals flushClassNameCache.
	ScrollBar initializeImagesCache.
	FreeTypeFontProvider current initialize.
	NaturalLanguageTranslator classPool at: #AllKnownPhrases put: nil.
	FreeTypeFontProvider current initialize.
	SystemNavigation default
		allObjectsDo: [ :each | 
			(each respondsTo: #releaseCachedState)
				ifTrue: [ each releaseCachedState ] ].
	3 timesRepeat: [ 
		Smalltalk garbageCollect.
		Symbol compactSymbolTable ].
	HashedCollection rehashAll.
	
	"Remove empty categories, which are not in MC packages, because MC does
	not do this (this script does not make packages dirty)"
	Smalltalk organization removeEmptyCategories.
	Smalltalk
		allClassesAndTraitsDo: [ :class |
			[ :each |
				each
					removeEmptyCategories;
					sortCategories ]
						value: class organization;
						value: class class organization ].
	PackageOrganizer default packages
		do: [ :each | each methods ifEmpty: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'.
	Smalltalk organization sortCategories.
	ChangeSet removeChangeSetsNamedSuchThat: [ :each | true ].
	ChangeSet resetCurrentToNewUnnamedChangeSet.
	Smalltalk garbageCollect.
	Author reset! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 6/5/2010 11:12'!
cleanUpMethods
	"Make sure that all methods in use are restarted"
	"ScriptLoader new cleanUpMethods"

	WeakArray restartFinalizationProcess.
	MethodChangeRecord allInstancesDo: [:x | x noteNewMethod: nil].
	WorldState allInstancesDo: [ :ws | ws convertAlarms; convertStepList; resetWorldMenu].
	WorldState allInstancesDo: [ :ws | ws instVarNamed: 'menuBuilder' put: nil ].
	ExternalDropHandler initialize.
	ScrollBar initializeImagesCache.
	GradientFillStyle initPixelRampCache.
	ProcessBrowser initialize.
	Smalltalk garbageCollect.
	Delay startTimerEventLoop! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 12/5/2009 11:19'!
cleanUpPackageOrganizer

	PackageOrganizer default packages
		do: [ :each | 
			each methods isEmpty
				ifTrue: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'! !

!ScriptLoader methodsFor: 'public' stamp: 'StephaneDucasse 11/18/2010 22:58'!
commentForCurrentUpdate
 ^ '- Issue 3210:	SimpleMorphic Integration. Part two and three.
	-SMx02-PharoEnhAndPreliminariesCoda.1.cs contains some refactorings needed to make it possible to add another GUI to Pharo. 
	- SMx03-ExtensionMethodsPart1.3.cs contains a few useful methods, not specific to SimpleMorphic, but optional anyway. You might integrate this into Pharo or consider it part of SimpleMorphic.'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 14:36'!
compileNewUpdateMethod
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethod)
		classified: 'pharo - updates'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 13:26'!
compileScriptMethodWithCurrentPackages: aNumber 
	"ScriptLoader new compileScriptMethodWithCurrentPackages: 9999"
	
	self class compile: 
		(self newGenerateScriptTemplateWithCurrentPackages: aNumber)
		classified: 'pharo - scripts'! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
copyPackagesFromWaitingFolderToHomeRepository
	"self defaultMCWaitingFolder allFileNames"
	"self new copyPackageFromWaitingFolderToHomeRepository"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		self repository storeVersion: version]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'al 11/1/2008 19:49'!
currentPackages
	"self new currentPackages" 
	
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies reject: [:each |
		self packagesNotToSavePatternNames
			anySatisfy: [:p | p match: each package name]].
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:08'!
currentScriptVersionNumber
	^ CurrentScriptVersionNumber! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 9/8/2009 14:41'!
currentUpdateVersionNumber
	^ CurrentUpdateVersionNumber ifNil: [SystemVersion current highestUpdate]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 5/29/2006 20:52'!
currentVersions
	"ScriptLoader new currentVersions"
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies collect:
		[:ea |  ea ancestry ancestorString ]! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:46'!
deletePackage: aString

	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	MCWorkingCopy registry removeKey: toRemove package.! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 5/3/2010 22:54'!
doneApplyingChanges
	| comment commentQuoted st |
	SmalltalkImage current saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	
	comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		centerAt: Sensor cursorPoint
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self].
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteLocalFiles.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersion.
	self saveLatestScriptLoaderToWaitingFolder.
	
	self inform: 'Update prepared and ready to be verified.'! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/15/2010 12:33'!
fixObsoleteReferences
	"self new fixObsoleteReferences"
	CompiledMethod allInstances
		do: [ :method | 
			| obsoleteBindings |
			obsoleteBindings := method literals
				select: [ :literal | literal isVariableBinding 
									and: [ literal value isBehavior and: [ literal value isObsolete ]] ].
			obsoleteBindings
				do: [ :binding | 
					| realClass obsName realName |
					obsName := binding value name.
					Transcript
						show: obsName;
						cr.
					realName := obsName copyReplaceAll: 'AnObsolete' with: ''.
					realClass := Smalltalk globals at: realName asSymbol ifAbsent: [ UndefinedObject ].
					binding key: binding key value: realClass ] ].
	Behavior flushObsoleteSubclasses.
	Smalltalk
		garbageCollect;
		garbageCollect.
	SystemNavigation default obsoleteBehaviors size > 0
		ifTrue: [ SystemNavigation default obsoleteBehaviors inspect ]! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 3/14/2010 12:44'!
flushCaches

	MCFileBasedRepository flushAllCaches.
	MCDefinition clearInstances.
	Smalltalk garbageCollect.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 8/14/2008 16:06'!
generateCS: packageInfo fromUpdate: updateNumber on: st
	
	st nextPutAll:
'"Postscript:
Leave the line above, and replace the rest of this comment by a useful one.
Executable statements should follow this comment, and should
be separated by periods, with no exclamation points (!!!!).
Be sure to put any further comments in double-quotes, like this one."

|repository|
repository := MCHttpRepository
                location: ''http://www.squeaksource.com/Pharo/''
                user: ''''
                password: ''''.
(repository loadVersionFromFileNamed:' .
	st nextPut: $' ; nextPutAll: packageInfo, '.mcz'') load.'; cr.
	st nextPutAll: 'ScriptLoader new update', (updateNumber) asString; nextPutAll: '.' ; cr.
	st nextPutAll: '!!'.
	^ st contents
! !

!ScriptLoader methodsFor: 'utils' stamp: 'stephane.ducasse 7/4/2009 12:27'!
generateCompleteFixList
	"generateCompleteFixList"
	| stream |
	stream := (FileStream newFileNamed: 'changes-log.txt').
	[ stream nextPutAll: ScriptLoader new logStream contents ] ensure: [ stream close ]! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 8/30/2009 14:48'!
generateNewUpdateMethod
	"ScriptLoader new generateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, '.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:05'!
generateScriptAndUpdateMethodForNewVersion
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethod.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 14:41'!
generateScriptTemplateWithAllCurrentPackages
	"ScriptLoader new generateScriptTemplateWithAllCurrentPackages"
	
	| str |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'scriptXXX' ; cr ; cr ; tab.
	str nextPutAll: '| names|'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	self currentVersionsToBeSaved do: 
		[:each |
			str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 18:07'!
generateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '| names |'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'al 11/1/2008 18:15'!
getLatestScriptNumber
	"self new getLatestScriptNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'script*' match: each ].
	upfroms := upfroms collect: [:each | (each asString allButFirst: 6)].
	upfroms := upfroms reject: [:each | '*Log*' match: each ].
	upfroms := upfroms reject: [:each | '*XXX*' match: each ].
	upfroms := upfroms collect: [:each | each asNumber].
	^ upfroms asSortedCollection last
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 10/17/2009 12:33'!
getLatestUpdateNumber
	"self new getLatestUpdateNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'update*' match: each ].
	upfroms := upfroms collect: [:each | [(each asString last: 5) asNumber] on: Error do: [0]].
	^ upfroms asSortedCollection last! !

!ScriptLoader methodsFor: 'accessing' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			self
				installGofer;
				gofer ]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'CarloTeixeira 8/11/2010 00:37'!
inboxRepository
	^ inboxRepository ifNil: [inboxRepository :=  MCHttpRepository inboxRepository]
	! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 7/10/2009 18:07'!
installGofer
	"self new installGofer"
	
	self class loadLatestPackage: 'Gofer' from: 'http://source.lukas-renggli.ch/flair'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 14:46'!
installRepository: aString for: packageName

	(MCWorkingCopy allManagers select: [:each | each package name = packageName])
		first repositoryGroup
		addRepository: (MCHttpRepository new location: aString ; user: '' ; password: '')
		! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'alain.plantec 2/6/2009 15:49'!
installVersionInfo
	"self new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' translated initialAnswer: '3.9' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	
! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 3/14/2010 21:13'!
installingInstaller
	"self new installingInstaller"

	| mc files fileToLoad version |
	mc := Smalltalk globals
		at: #MCHttpRepository
		ifPresent: [ :repoClass | repoClass location: 'www.squeaksource.com/Installer' user: 'squeak' password: 'squeak' ].
	files := mc readableFileNames
		asSortedCollection: [ :a :b | 
			[ (a findBetweenSubStrs: #($.)) allButLast last asInteger > (b findBetweenSubStrs: #($.)) allButLast last asInteger ]
				on: Error
				do: [ :ex | false ] ].
	fileToLoad := files detect: [ :aFile | aFile beginsWith: 'Installer-Core' ] ifNone: [ nil ].
	version := mc versionFromFileNamed: fileToLoad.
	version workingCopy repositoryGroup addRepository: mc.
	mc creationTemplate: mc asCreationTemplate.
	version load.
	^ Smalltalk globals at: #Installer! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 8/14/2008 16:03'!
latestScriptLoaderPackageIdentificationString
	"ScriptLoader new latestScriptLoaderPackageIdentificationString"
	
	^  self allCurrentVersions detect: [:each | 'ScriptLoader*' match: each ]
	! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'Jb 10/23/2010 12:14'!
launchUpdate

	UpdateStreamer new updateFromServer! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:06'!
loadLatestScriptloader
	"self new loadLatestScriptloader"
	
	self class 
		loadLatestPackage: 'ScriptLoader', self currentMajorVersionNumberWithoutDot 
		fromSqueaksource: 'Pharo' 
	

! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 10/23/2010 15:03'!
loadLatestUpdateList
	"fetch the latest version of the update.list on the server"
	
	| listToUse lastUpdate |
	listToUse := (HTTPClient httpGet: UpdateStreamer new updateFolderURL , 'updates.list') contents.
				
	listToUse linesDo: [:each | lastUpdate := each].
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			FileDirectory default
				forceNewFileNamed: 'updates.list'
				do: [:stream | stream nextPutAll: listToUse]]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'nice 1/5/2010 15:59'!
loadOneAfterTheOther: aCollection merge: aBoolean
	
	(self newerVersionsIn: aCollection)
		do: [:fn | | loader |
			loader := aBoolean
				ifTrue: [ MCVersionMerger new ]
				ifFalse: [ MCVersionLoader new].
			loader addVersion: (self repository loadVersionFromFileNamed: fn).
			aBoolean
				ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
							request merger conflicts isEmpty
								ifTrue: [request resume: true]
								ifFalse: [request pass]]]
				ifFalse: [loader load]]
  	  	displayingProgress: 'Loading versions...'.
	

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'adrian_lienhard 2/21/2009 13:40'!
loadOneAfterTheOther: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadOneAfterTheOther: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			self loadOneAfterTheOther: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
loadPackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		version load]! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'michael.rueger 1/13/2009 15:26'!
loadTogether: aCollection merge: aBoolean
	| loader |
	loader := aBoolean
		ifTrue: [ MCVersionMerger new ]
		ifFalse: [ MCVersionLoader new].
	(self newerVersionsIn: aCollection)
		do: [:fn | loader addVersion: (self loadVersionFromFileNamed: fn)]
  	  	displayingProgress: 'Adding versions...'.
	aBoolean
		ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
					request merger conflicts isEmpty
						ifTrue: [request resume: true]
						ifFalse: [request pass]]]
		ifFalse: [loader hasVersions ifTrue: [loader load]]

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 5/10/2008 12:41'!
loadTogether: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadTogether: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			 self loadTogether: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'private' stamp: 'michael.rueger 1/13/2009 15:25'!
loadVersionFromFileNamed: fn
	| version |
	version := self repository loadVersionFromFileNamed: fn.
	^version
		ifNil: [self inboxRepository loadVersionFromFileNamed: fn]! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 4/4/2008 14:47'!
log: aString

	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/15/2008 18:30'!
logContents

	^ self logStream contents! !

!ScriptLoader methodsFor: 'log' stamp: 'adrian_lienhard 3/16/2009 21:30'!
logStream
	^ LogStream ifNil: [
		LogStream := ReadWriteStream on: (String new: 1000)]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
mergePackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles
		do: [ :name | | version |
			version := self class defaultMCWaitingFolder  versionFromFileNamed: name.
			version merge.
			]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'AdrianLienhard 6/5/2010 11:08'!
metacelloRepository
	^ (MCHttpRepository 
		location: 'http://www.squeaksource.com/MetacelloRepository'
		user: ''
		password: '')
	! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:35'!
newGenerateNewUpdateMethod
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:25'!
newGenerateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	"this version change the script to only "
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '^ '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr'.
	^ str contents! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 10/13/2005 21:44'!
newerVersionsIn: aCollection
	^aCollection reject: [:each |
		MCWorkingCopy allManagers anySatisfy: [:workingcopy |
			workingcopy ancestry ancestorString , '.mcz' = each]].! !

!ScriptLoader methodsFor: 'utils' stamp: 'sd 2/4/2008 16:09'!
openWindow: contents label: aLabel

	StringHolder new 
		contents: contents ;
		openLabel: aLabel! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 7/17/2010 13:35'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'AST*'
			'*Refactoring*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
			'*OB-*'
			'OmniBrowser*'
		).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 7/7/2010 23:23'!
prepareNewUpdate
	self launchUpdate.
	self loadLatestScriptloader.
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodate ifFalse: [self loadLatestUpdateList].
	self checkImageIsUptodate ifFalse: [
		^ self inform: 'Your update.list and your image are not in sync!! Please use a fresh image and download the latest update.list and start over. May be you are doing a rollback and you should remove the bogus ScriptLoader version from the Pharo repository' ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	self inform: 'The new version number is ' , self currentUpdateVersionNumber asString , '. Ready to apply changes now.', String cr, 'You are now running in image ', (FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName)).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 5/3/2010 21:07'!
publishChanges
	| username password changescriptname changesetFilename str strings|
	(FileStream isAFileNamed: 'PharoPass.txt') 
		ifTrue: [ str := FileStream fileNamed:  'PharoPass.txt'. 
				strings := str contents substrings.
				username := strings first.
				password := strings second] 
		ifFalse: [ username := UIManager default request: 'Pharo repository login'.
			     password := UIManager default requestPassword: 'Pharo repository password'.].

	self setToRepositoriesPassword: password to: username.
	
	changescriptname := UIManager default request: 'Changeset name (no space)' initialAnswer: 'WhatAsChanged'.
	changesetFilename := self CSForLastUpdateAndPatchUpdatesList: changescriptname.
	self copyPackagesFromWaitingFolderToHomeRepository.
	self announceOnMailingList.
	self inform: 'All packages have been uploaded to the Pharo repository.
Remaining manual steps:
1) ./upFiles ',changesetFilename,'
2) ./upFiles updates.list
3) Announce new update on mailing list'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 22:30'!
removeAllHTTPRepositories: aColl
	"self new removeAllRepositories: 
			#('http://source.squeakfoundation.org/inbox/'
			 'http://source.squeakfoundation.org/39a/'
			 'http://source.squeakfoundation.org/Balloon/'
			 'http://source.squeakfoundation.org/Compression/'
			 'http://source.squeakfoundation.org/Graphics/'
			  'http://source.wiresong.ca/mc/')"
 
	
	MCWorkingCopy allManagers do: [:each | 
		aColl
			do: [:location | 
					each  repositoryGroup removeHTTPRepositoryLocationNamed: location]].
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 3/11/2010 20:22'!
removeAllRepositories
	"self new removeAllRepositories"
	
	MCWorkingCopy allManagers do: [:each |  each  repositoryGroup initialize].
	MCRepositoryGroup default initialize.
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/15/2010 13:16'!
removeDejaVuFonts
	"Note, you need to close all windows to make the Deja Vu fonts being GCed"

	StandardFonts setDefaultFonts: #(
		(defaultFont: 'Accuny' 10)
		(codeFont: 'Accuny' 10)
		(listFont: 'Accuny' 10)
		(menuFont: 'Accuny' 10)
		(windowTitleFont: 'Accuny' 10)
		(balloonFont: 'Accuny' 10)
		(buttonFont: 'Accuny' 10)).
	TextConstants removeKey: 'Bitmap DejaVu Sans'! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:06'!
removeScriptMethods
	"self new removeScriptMethods"
	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - scripts') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:04'!
removeUpdateMethods

	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - updates') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:41'!
repository
	^ repository ifNil: [
		repository := MCHttpRepository new
			location:  'http://www.squeaksource.com/Pharo';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:48'!
repository310
	^ repository310 ifNil: [
		repository310 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/310';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repository39
	^ repository39 ifNil: [
		repository39 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/39a';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:42'!
repository: aRepository
	repository := aRepository! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/14/2009 10:32'!
repositoryMC
	^ repositoryMC ifNil: [
		repositoryMC := MCHttpRepository new
			location:  'http://source.wiresong.ca/mc';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repositorySqueakTrunk
	^ repositorySqueakTrunk ifNil: [
		repositorySqueakTrunk := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/trunk';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:59'!
repositoryTaskForces
	^ repositoryTaskForces ifNil: [
		repositoryTaskForces := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTaskForces';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/26/2009 07:47'!
repositoryTreated
	^ repositoryTreated ifNil: [
		repositoryTreated := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTreatedInbox';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:30'!
saveAsImageAsTestImage
	"Now you can run tests and see and go back to the previous image
	and do that go and back.... then after you can decide to freeze"

	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-imageForTestsFor')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'DamienCassou 9/8/2009 14:42'!
saveAsNewImageWithCurrentReleaseName
	|name|
	name := FileDirectory default
				nextNameFor: ('releasePharo-',  self currentUpdateVersionNumber asString)
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:31'!
saveAsNewImageWithCurrentReleaseNameToPublish
	"If the reload failed and you do not want to lose time reload all the cs and packages... you can now restart from the image saved now"
	
	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-releasePharoToPublish')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'al 11/1/2008 18:33'!
saveChangedPackagesIntoWaitingFolder
	self currentChangedPackages do: [:each |
		self
			saveInToReloadCachePackage: each
			with: self commentForCurrentUpdate]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 11/9/2010 18:38'!
saveImageForRunningTests

	| comment commentQuoted st resuming |
	resuming := false.
	SmalltalkImage current saveSession
		ifFalse: [ resuming := true].
	resuming ifTrue: [
		self saveAsImageAsTestImage.
	
		self inform: 'Now you can use this image named ''Test'' to run the tests and come back to fix problems in the \ previous one and eventually freeze it by selecting the next step, in either one.' withCRs]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'adrianLienhard 11/2/2008 00:31'!
saveInToReloadCachePackage: aWorkingCopy with: aMessageString
	self
		savePackage: aWorkingCopy
		in: self class defaultMCWaitingFolder
		with: aMessageString! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/28/2010 20:06'!
saveLatestScriptLoaderToHome
	"self new saveLatestScriptLoaderToHome"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader*' match: each  package name].
	self repository storeVersion: r first newVersion.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:31'!
saveLatestScriptLoaderToWaitingFolder
	"self new saveLatestScriptLoaderToWaitingFolder"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader', self currentMajorVersionNumberWithoutDot, '*' match: each  package name].
	self
		saveInToReloadCachePackage: r first
		with: self commentForCurrentUpdate! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 10/20/2009 11:28'!
savePackage: aWorkingCopy in: aRepository with: aMessageString
	" | sc |
	  sc := self new.
	  sc savePackage: (self new workingCopyFromPackageName: 'ScriptLoader11') 
		in: MCCacheRepository default
		with: 'this is test to automate dirty package saving in cache'"

	aRepository storeVersion: (aWorkingCopy 
		newVersionWithName: aWorkingCopy uniqueVersionName
		message: aMessageString)! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 13:21'!
script0! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 13:34'!
script1

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.52.mcz
Collections-Strings-MarcusDenker.125.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.476.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-MarcusDenker.47.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.28.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.152.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.250.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.39.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-MarcusDenker.689.mcz
KernelTests-MarcusDenker.264.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.619.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.178.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-MarcusDenker.42.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.50.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.32.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-MarcusDenker.35.mcz
NetworkTests-StephaneDucasse.30.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-MarcusDenker.133.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.9.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.68.mcz
System-Clipboard-StephaneDucasse.16.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-MarcusDenker.49.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.97.mcz
System-Platforms-StephaneDucasse.7.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-MarcusDenker.302.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-MarcusDenker.176.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.407.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-StephaneDucasse.372.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/22/2010 18:45'!
script10

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.56.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.694.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.628.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.29.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.196.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.187.mcz
ToolBuilder-Kernel-StephaneDucasse.53.mcz
ToolBuilder-Morphic-StephaneDucasse.77.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/21/2010 22:08'!
script100

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-MarcusDenker.233.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.687.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.15.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.334.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/21/2010 23:07'!
script101

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-MarcusDenker.233.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.171.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.687.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.15.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.48.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.334.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/22/2010 21:09'!
script102

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.144.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-MarcusDenker.233.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.171.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.687.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.15.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.49.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.334.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/22/2010 21:43'!
script103

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.144.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.171.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.687.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.15.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.334.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/22/2010 22:24'!
script104

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.144.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.171.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.687.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.334.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/23/2010 19:41'!
script105

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.144.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.171.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.272.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.688.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.282.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.335.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.210.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.93.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.5.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/24/2010 22:43'!
script106

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.144.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.171.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.272.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.735.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.690.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.282.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.335.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.210.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.93.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.5.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/24/2010 22:59'!
script107

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.144.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.171.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.272.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.735.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.690.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.57.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.282.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.335.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.210.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.93.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.5.mcz
VB-Regex-AdrianLienhard.48.mcz
WebClient-Core-StephaneDucasse.71.mcz
WebClient-Tests-StephaneDucasse.13.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/25/2010 19:30'!
script108

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.144.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.171.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.272.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.736.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.690.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.57.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.282.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.335.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.210.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.93.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.5.mcz
VB-Regex-AdrianLienhard.48.mcz
WebClient-Core-StephaneDucasse.73.mcz
WebClient-Tests-StephaneDucasse.13.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/25/2010 22:41'!
script109

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.145.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.273.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.737.mcz
KernelTests-StephaneDucasse.281.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.480.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.691.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.40.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.282.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.144.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.335.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.210.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.93.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.5.mcz
VB-Regex-AdrianLienhard.48.mcz
WebClient-Core-StephaneDucasse.73.mcz
WebClient-Tests-StephaneDucasse.13.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/26/2010 18:32'!
script11

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.694.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.629.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.32.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.187.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/26/2010 11:31'!
script110

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.145.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.273.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.738.mcz
KernelTests-StephaneDucasse.281.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.480.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.692.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.41.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.335.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.210.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.93.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.5.mcz
VB-Regex-AdrianLienhard.48.mcz
WebClient-Core-StephaneDucasse.73.mcz
WebClient-Tests-StephaneDucasse.13.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/26/2010 21:02'!
script111

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.234.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.273.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.738.mcz
KernelTests-StephaneDucasse.281.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.480.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.693.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.41.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.335.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.210.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.93.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.5.mcz
VB-Regex-AdrianLienhard.48.mcz
WebClient-Core-StephaneDucasse.73.mcz
WebClient-Tests-StephaneDucasse.13.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/27/2010 11:44'!
script112

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.235.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.274.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.15.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.739.mcz
KernelTests-StephaneDucasse.283.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.41.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.110.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.336.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz
WebClient-Core-StephaneDucasse.73.mcz
WebClient-Tests-StephaneDucasse.13.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/27/2010 15:13'!
script113

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.235.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.274.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.15.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.739.mcz
KernelTests-StephaneDucasse.283.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.41.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.110.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.336.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz
WebClient-Core-StephaneDucasse.75.mcz
WebClient-Tests-StephaneDucasse.13.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/27/2010 16:10'!
script114

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.235.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.274.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.15.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.740.mcz
KernelTests-StephaneDucasse.283.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.41.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.110.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.336.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz
WebClient-Core-StephaneDucasse.75.mcz
WebClient-Tests-StephaneDucasse.13.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/31/2010 20:02'!
script115

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.235.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.274.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.15.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.740.mcz
KernelTests-StephaneDucasse.284.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.41.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.110.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.336.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/1/2010 08:57'!
script116

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.238.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.278.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.742.mcz
KernelTests-StephaneDucasse.284.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.41.mcz
NetworkTests-StephaneDucasse.38.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.110.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.336.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/1/2010 14:43'!
script117

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.278.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.743.mcz
KernelTests-StephaneDucasse.285.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.110.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.336.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/1/2010 17:15'!
script118

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.278.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.743.mcz
KernelTests-StephaneDucasse.285.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.110.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.341.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/3/2010 13:41'!
script119

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.172.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.278.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.743.mcz
KernelTests-StephaneDucasse.285.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.24.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.58.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.25.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.110.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.341.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/26/2010 20:23'!
script12

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.694.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.630.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.34.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.188.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.9.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/3/2010 21:43'!
script120

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.174.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.278.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.743.mcz
KernelTests-StephaneDucasse.285.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.694.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.283.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.342.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.29.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/4/2010 13:38'!
script121

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-MarcusDenker.56.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.174.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.278.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.743.mcz
KernelTests-StephaneDucasse.285.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.696.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.285.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.342.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.31.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.441.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/8/2010 19:18'!
script122

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.174.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.278.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.747.mcz
KernelTests-StephaneDucasse.285.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.699.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.285.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.342.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.33.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.446.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/8/2010 21:30'!
script123

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.174.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.278.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.748.mcz
KernelTests-StephaneDucasse.286.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.699.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.285.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.342.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.33.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.446.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/9/2010 10:54'!
script124

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.280.mcz
Graphics-Display Objects-StephaneDucasse.12.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.750.mcz
KernelTests-StephaneDucasse.286.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.701.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.287.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.12.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.344.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.33.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/9/2010 11:39'!
script125

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.280.mcz
Graphics-Display Objects-StephaneDucasse.12.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.751.mcz
KernelTests-StephaneDucasse.286.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.701.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.287.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.12.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.346.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.33.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.211.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/9/2010 14:58'!
script126

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.280.mcz
Graphics-Display Objects-StephaneDucasse.12.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.751.mcz
KernelTests-StephaneDucasse.286.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.701.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.287.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.347.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.33.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/9/2010 15:15'!
script127

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.281.mcz
Graphics-Display Objects-MarcusDenker.13.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.752.mcz
KernelTests-StephaneDucasse.286.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.702.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.347.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.33.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/9/2010 21:16'!
script128

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.282.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.753.mcz
KernelTests-StephaneDucasse.287.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.703.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.347.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.33.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/10/2010 14:34'!
script129

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.102.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.282.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.753.mcz
KernelTests-StephaneDucasse.287.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.703.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.347.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.34.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/26/2010 21:02'!
script13

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.695.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.630.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.36.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.188.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.9.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/10/2010 14:49'!
script130

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.282.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.703.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.348.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.34.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/10/2010 17:03'!
script131

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.68.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.703.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.348.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.34.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/10/2010 18:20'!
script132

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.703.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.348.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.34.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/11/2010 17:56'!
script133

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.703.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.77.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.348.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.34.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/11/2010 18:10'!
script134

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.176.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.59.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.703.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.78.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.349.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.34.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/12/2010 10:43'!
script135

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.67.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-StephaneDucasse.240.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.178.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.704.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.79.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.350.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.34.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.212.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.448.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/12/2010 15:21'!
script136

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.67.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.178.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.1.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.705.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.288.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.350.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.36.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.450.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/12/2010 18:00'!
script137

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.67.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.178.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.1.mcz
Graphics-Display Objects-StephaneDucasse.14.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.6.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.706.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.289.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.201.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.350.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.36.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.451.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/13/2010 14:14'!
script138

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.67.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.179.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.281.mcz
Graphics-Display Objects-StephaneDucasse.15.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.706.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.289.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.350.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.36.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.451.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/15/2010 15:46'!
script139

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.107.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.67.mcz
Collections-Strings-MarcusDenker.146.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.485.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.179.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.281.mcz
Graphics-Display Objects-StephaneDucasse.15.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.754.mcz
KernelTests-StephaneDucasse.288.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.706.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.289.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.350.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.36.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.451.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/26/2010 22:52'!
script14

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.695.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.38.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.190.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.9.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/18/2010 21:58'!
script140

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.108.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.67.mcz
Collections-Strings-StephaneDucasse.147.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.179.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.281.mcz
Graphics-Display Objects-StephaneDucasse.15.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.755.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.707.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.289.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.350.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.37.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.451.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/23/2010 14:29'!
script141

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.108.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.39.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.181.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.281.mcz
Graphics-Display Objects-StephaneDucasse.15.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.755.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.709.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.289.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.145.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.352.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.37.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.453.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/24/2010 21:08'!
script142

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.108.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.181.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.281.mcz
Graphics-Display Objects-StephaneDucasse.15.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.758.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.710.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.40.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.289.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.352.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.37.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.454.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/24/2010 22:07'!
script143

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.108.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.183.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.282.mcz
Graphics-Display Objects-StephaneDucasse.17.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.61.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.759.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.711.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.289.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.352.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.37.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.455.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/27/2010 15:36'!
script144

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.110.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.183.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.282.mcz
Graphics-Display Objects-StephaneDucasse.17.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.760.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.711.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.352.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.37.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.455.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'stephaneDucasse 9/28/2010 11:40'!
script145

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.110.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.183.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.282.mcz
Graphics-Display Objects-StephaneDucasse.17.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.19.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.760.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.711.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneDucasse.354.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.37.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-stephaneDucasse.457.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/28/2010 11:51'!
script146

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.110.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.183.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.283.mcz
Graphics-Display Objects-StephaneDucasse.27.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.30.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.760.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.711.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneDucasse.354.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.37.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-stephaneDucasse.457.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/28/2010 14:21'!
script147

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.110.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.183.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.284.mcz
Graphics-Display Objects-StephaneDucasse.27.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.31.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.760.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.722.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.362.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.37.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-stephaneDucasse.457.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/28/2010 14:37'!
script148

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.110.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-StephaneDucasse.ducasse.183.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.27.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.31.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.760.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.722.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.362.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.38.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.214.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-stephaneDucasse.457.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/28/2010 21:11'!
script149

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.110.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.241.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.185.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.27.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.31.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.760.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.722.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.364.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.217.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-stephaneDucasse.457.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/27/2010 18:24'!
script15

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.696.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.40.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.309.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.9.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/29/2010 09:27'!
script150

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.110.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.243.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.69.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.185.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.27.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.31.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.760.mcz
KernelTests-StephaneDucasse.289.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.722.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.80.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.366.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-stephaneDucasse.457.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/29/2010 13:49'!
script151

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.110.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.149.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.42.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.243.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-MarcusDenker.71.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.27.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.31.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.5.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.761.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.722.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.25.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.42.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.147.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.81.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.107.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.367.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.458.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.6.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/30/2010 11:13'!
script152

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.112.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.46.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.243.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.73.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.32.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.11.mcz
Graphics-Primitives-StephaneDucasse.35.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.768.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.8.mcz
Monticello-StephaneDucasse.481.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.727.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.6.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.29.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.153.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.81.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.368.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.467.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.12.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/30/2010 11:36'!
script153

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.112.mcz
Collections-Arrayed-StephaneDucasse.53.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.47.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.243.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.33.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.36.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.768.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.8.mcz
Monticello-StephaneDucasse.484.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.728.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.29.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.61.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.81.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.369.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.467.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.12.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/30/2010 12:34'!
script154

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.243.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.33.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.769.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.8.mcz
Monticello-StephaneDucasse.484.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.729.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.30.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.62.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.81.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.370.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.468.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 9/30/2010 13:22'!
script155

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.243.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.33.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.769.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-StephaneDucasse.484.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.729.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.62.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.81.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.370.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.468.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-StephaneDucasse.10.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 9/30/2010 14:02'!
script156

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.62.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.769.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.484.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.730.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.62.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-MarcusDenker.19.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.81.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.370.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.468.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/1/2010 10:03'!
script157

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.769.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.484.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.730.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.62.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-MarcusDenker.19.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.81.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.370.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.41.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.469.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/1/2010 16:07'!
script158

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.769.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.484.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.730.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.64.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-MarcusDenker.19.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-MarcusDenker.81.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.371.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.43.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.469.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/1/2010 16:16'!
script159

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.769.mcz
KernelTests-MarcusDenker.291.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.484.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.731.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.64.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-MarcusDenker.19.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.371.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.44.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.470.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/27/2010 22:15'!
script16

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.42.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.409.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/1/2010 16:43'!
script160

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.484.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.731.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.64.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-MarcusDenker.19.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.371.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.470.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/1/2010 17:06'!
script161

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.732.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.64.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-MarcusDenker.290.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-MarcusDenker.19.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.371.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.470.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/1/2010 17:25'!
script162

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.732.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.64.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-MarcusDenker.19.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.371.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.471.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/1/2010 17:53'!
script163

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.732.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.64.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40111.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-MarcusDenker.19.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.371.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.471.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/2/2010 18:17'!
script164

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.732.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.31.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.64.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.371.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.219.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.472.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/3/2010 15:19'!
script165

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.732.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.373.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.221.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.473.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/4/2010 19:37'!
script166

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.732.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.373.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.221.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/5/2010 11:35'!
script167

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.732.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.12.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.373.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.221.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/5/2010 12:08'!
script168

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.732.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.13.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.373.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.221.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/5/2010 18:36'!
script169

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.48.mcz
CollectionsTests-StephaneDucasse.486.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.59.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.772.mcz
KernelTests-StephaneDucasse.293.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.733.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.373.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.45.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.222.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/28/2010 15:28'!
script17

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.128.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.253.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.182.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.44.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.409.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/7/2010 14:09'!
script170

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-MarcusDenker.50.mcz
CollectionsTests-MarcusDenker.488.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.773.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.733.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.292.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.375.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.46.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.222.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/9/2010 08:33'!
script171

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.69.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-MarcusDenker.50.mcz
CollectionsTests-MarcusDenker.488.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.773.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.486.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.736.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.295.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.375.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.222.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/11/2010 09:44'!
script172

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-MarcusDenker.50.mcz
CollectionsTests-MarcusDenker.488.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.774.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.487.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.736.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.295.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.376.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.222.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/11/2010 15:19'!
script173

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-MarcusDenker.50.mcz
CollectionsTests-MarcusDenker.488.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.775.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.487.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.736.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.296.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.376.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.222.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.383.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/11/2010 16:32'!
script174

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-MarcusDenker.50.mcz
CollectionsTests-MarcusDenker.488.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.776.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.487.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.737.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.296.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.377.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/11/2010 17:01'!
script175

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.776.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.487.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.737.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.296.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.377.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/12/2010 13:10'!
script176

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.776.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.487.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.737.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.377.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.474.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/12/2010 22:24'!
script177

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.777.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.488.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.737.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.377.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.475.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/12/2010 23:13'!
script178

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.777.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.488.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.737.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.377.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.476.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/17/2010 20:55'!
script179

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.113.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.79.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.777.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.488.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.737.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.16.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40112.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.9.mcz
Settings-Tools-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.378.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.476.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/28/2010 15:49'!
script18

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.128.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.253.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.183.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.46.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.409.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/18/2010 14:57'!
script180

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.80.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.778.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.488.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.737.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.9.mcz
Settings-Tools-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.378.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.476.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/19/2010 14:07'!
script181

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.779.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.488.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.739.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40113.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.9.mcz
Settings-Tools-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.378.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.476.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/19/2010 14:37'!
script182

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.779.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.488.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.739.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.9.mcz
Settings-Tools-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.378.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.476.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/19/2010 14:52'!
script183

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.779.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.489.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.739.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.9.mcz
Settings-Tools-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.378.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.49.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.223.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.94.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.476.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.13.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/19/2010 21:52'!
script184

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.72.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.60.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.5.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-MarcusDenker.63.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.489.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.739.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.40.mcz
Polymorph-Widgets-StephaneDucasse.297.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.154.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.4.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.11.mcz
Settings-Tools-StephaneDucasse.12.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.202.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.381.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.51.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.225.mcz
ToolBuilder-Kernel-StephaneDucasse.59.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.477.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/20/2010 22:37'!
script185

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.62.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.489.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.743.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.301.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.11.mcz
Settings-Tools-StephaneDucasse.12.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.204.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.382.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.52.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.225.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.479.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/20/2010 22:52'!
script186

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.62.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.489.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.743.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.302.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.10.mcz
Settings-System-StephaneDucasse.11.mcz
Settings-Tools-StephaneDucasse.12.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.204.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.382.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.53.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.225.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.479.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/21/2010 11:47'!
script187

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-StephaneDucasse.153.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-StephaneDucasse.62.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.490.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.744.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.303.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-StephaneDucasse.11.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.109.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.204.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.382.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.53.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.226.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.479.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/23/2010 12:09'!
script188

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.154.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.63.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.491.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.745.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-StephaneDucasse.65.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.303.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-StephaneDucasse.11.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.110.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.204.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.383.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.53.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.227.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.479.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/23/2010 12:43'!
script189

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.154.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.63.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.7.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.493.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.74.mcz
Morphic-MarcusDenker.747.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.42.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.305.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-StephaneDucasse.11.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.110.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.204.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.385.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-StephaneDucasse.53.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.229.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.482.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.11.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/28/2010 16:40'!
script19

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.128.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.253.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.183.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.48.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.410.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/23/2010 14:28'!
script190

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.154.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.493.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.74.mcz
Morphic-MarcusDenker.748.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.305.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.110.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.386.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.55.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.230.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.482.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/23/2010 15:16'!
script191

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.154.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.493.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.74.mcz
Morphic-MarcusDenker.748.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.305.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.110.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.387.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.55.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.231.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.482.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 10/23/2010 15:45'!
script192

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.154.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-StephaneDucasse.63.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.780.mcz
KernelTests-MarcusDenker.294.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.493.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.74.mcz
Morphic-MarcusDenker.748.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.305.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-StephaneDucasse.40114.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.110.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.388.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.55.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-StephaneDucasse.231.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.482.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/23/2010 16:48'!
script193

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.154.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.782.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.493.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.74.mcz
Morphic-MarcusDenker.748.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-StephaneDucasse.50.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-StephaneDucasse.39.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.306.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-MarcusDenker.40116.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.111.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.388.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.55.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.232.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.482.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/23/2010 17:10'!
script194

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-StephaneDucasse.55.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.154.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.538.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.34.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-StephaneDucasse.16.mcz
Graphics-Primitives-StephaneDucasse.37.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.782.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.493.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.74.mcz
Morphic-MarcusDenker.748.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.6.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.306.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-StephaneDucasse.82.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.111.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.388.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.55.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.233.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.483.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/24/2010 11:30'!
script195

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-MarcusDenker.56.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.155.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.35.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.38.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.783.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.494.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.74.mcz
Morphic-MarcusDenker.749.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.7.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.307.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.14.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.83.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.389.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.55.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.233.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.483.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/24/2010 16:44'!
script196

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-MarcusDenker.56.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.155.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.48.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.35.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.38.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.785.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.494.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.74.mcz
Morphic-MarcusDenker.752.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.7.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.310.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.83.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.391.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.58.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.233.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.483.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/24/2010 20:24'!
script197

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.115.mcz
Collections-Arrayed-MarcusDenker.56.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.155.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-StephaneDucasse.489.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.35.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.38.mcz
Graphics-Resources-StephaneDucasse.7.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.785.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.495.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.75.mcz
Morphic-MarcusDenker.752.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.7.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.67.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.310.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.83.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.391.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.58.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.234.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.484.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/25/2010 10:49'!
script198

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.116.mcz
Collections-Arrayed-MarcusDenker.56.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.155.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.35.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.38.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.785.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.496.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.754.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.7.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.313.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.83.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.391.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.58.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.234.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.485.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/25/2010 16:41'!
script199

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.116.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.186.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-MarcusDenker.35.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.9.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.40.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.787.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.496.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.754.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.7.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.316.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.156.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.83.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.392.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.59.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.235.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.485.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 15:16'!
script2

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.52.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.477.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.28.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.152.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.250.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.39.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-MarcusDenker.689.mcz
KernelTests-MarcusDenker.264.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.620.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.178.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-MarcusDenker.42.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.50.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.32.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-MarcusDenker.35.mcz
NetworkTests-StephaneDucasse.30.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-MarcusDenker.133.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.11.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.68.mcz
System-Clipboard-StephaneDucasse.16.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-MarcusDenker.49.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.97.mcz
System-Platforms-StephaneDucasse.7.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-MarcusDenker.302.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.177.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.407.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-StephaneDucasse.372.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/28/2010 20:08'!
script20

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.128.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.253.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.697.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.636.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.183.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Support-StephaneDucasse.310.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.54.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.410.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/26/2010 15:43'!
script200

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.2.mcz
Graphics-Display Objects-MarcusDenker.36.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.12.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.40.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.787.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.496.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.757.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.7.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-StephaneDucasse.32.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.318.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.157.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.83.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.392.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.60.mcz
System-Tools-StephaneDucasse.39.mcz
Tests-MarcusDenker.235.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.485.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/27/2010 10:19'!
script201

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.2.mcz
Graphics-Display Objects-MarcusDenker.36.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.12.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.40.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.787.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.496.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.757.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.7.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.318.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.157.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.83.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.393.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.61.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.1.mcz
Tests-MarcusDenker.235.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.485.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-StephaneDucasse.15.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/28/2010 16:59'!
script202

	^ 'Announcements-MarcusDenker.1.mcz
Announcements-Core-StephaneDucasse.6.mcz
Announcements-Slice-MarcusDenker.1.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.104.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.5.mcz
Graphics-Display Objects-MarcusDenker.39.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.15.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.787.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.496.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.760.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.7.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.318.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.160.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.86.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.396.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.61.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.1.mcz
Tests-MarcusDenker.235.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.486.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/29/2010 17:53'!
script203

	^ 'Announcements-MarcusDenker.1.mcz
Announcements-Core-StephaneDucasse.6.mcz
Announcements-Slice-MarcusDenker.1.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-StephaneDucasse.3.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.788.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.761.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.318.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.160.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.87.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.397.mcz
System-Tests-ChangeNotification-StephaneDucasse.4.mcz
System-Text-MarcusDenker.61.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.2.mcz
Tests-MarcusDenker.235.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.96.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.487.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
Updater-MarcusDenker.13.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/30/2010 17:24'!
script204

	^ 'Announcements-MarcusDenker.1.mcz
Announcements-Core-StephaneDucasse.6.mcz
Announcements-Slice-MarcusDenker.1.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Default-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.1.mcz
DolphinCompatibility-ValueAdapters-StephaneDucasse.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Environments-MarcusDenker.4.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HashedCollectionFixes-StephaneDucasse.3.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.788.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.318.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.160.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.89.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.397.mcz
System-Tests-ChangeNotification-MarcusDenker.5.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.2.mcz
Tests-MarcusDenker.237.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.489.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
Updater-MarcusDenker.14.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/31/2010 09:43'!
script205

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-StephaneDucasse.51.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.1.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.788.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.319.mcz
ST80-MarcusDenker.160.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.89.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.397.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-MarcusDenker.238.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.490.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 10/31/2010 17:37'!
script206

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.788.mcz
KernelTests-MarcusDenker.296.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.319.mcz
ST80-MarcusDenker.160.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.398.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-MarcusDenker.238.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.490.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/1/2010 08:10'!
script207

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.790.mcz
KernelTests-StephaneDucasse.297.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.319.mcz
ST80-MarcusDenker.160.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.398.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-MarcusDenker.238.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.490.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/2/2010 17:36'!
script208

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.790.mcz
KernelTests-StephaneDucasse.297.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.319.mcz
ST80-MarcusDenker.160.mcz
SUnit-MarcusDenker.40117.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.401.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-StephaneDucasse.239.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.490.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/2/2010 18:08'!
script209

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.790.mcz
KernelTests-StephaneDucasse.297.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.319.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.12.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.401.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-StephaneDucasse.239.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.490.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/30/2010 21:41'!
script21

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.59.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-Display Objects-StephaneDucasse.4.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.4.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.701.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.247.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.54.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.313.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.3.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 11/4/2010 13:49'!
script210

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.791.mcz
KernelTests-StephaneDucasse.297.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.59.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.401.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-MarcusDenker.240.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.492.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/8/2010 18:50'!
script211

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.792.mcz
KernelTests-StephaneDucasse.297.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.402.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-StephaneDucasse.241.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.492.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/9/2010 18:55'!
script212

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.792.mcz
KernelTests-StephaneDucasse.297.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.403.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-StephaneDucasse.241.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.492.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/11/2010 12:43'!
script213

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.793.mcz
KernelTests-StephaneDucasse.297.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.404.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-StephaneDucasse.243.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.492.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/11/2010 12:59'!
script214

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.8.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.793.mcz
KernelTests-StephaneDucasse.297.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.79.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.404.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-StephaneDucasse.243.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.492.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/11/2010 22:42'!
script215

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.8.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.794.mcz
KernelTests-StephaneDucasse.298.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.80.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.404.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-StephaneDucasse.243.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.493.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/11/2010 23:11'!
script216

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.8.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.794.mcz
KernelTests-StephaneDucasse.298.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.113.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.404.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-MarcusDenker.3.mcz
Tests-StephaneDucasse.243.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.495.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/13/2010 17:26'!
script217

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.794.mcz
KernelTests-StephaneDucasse.298.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.405.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.4.mcz
Tests-StephaneDucasse.244.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.495.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'HasBinding 11/13/2010 18:09'!
script218

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.794.mcz
KernelTests-StephaneDucasse.298.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.4.mcz
Tests-StephaneDucasse.244.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.495.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/13/2010 21:10'!
script219

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-MarcusDenker.244.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.794.mcz
KernelTests-StephaneDucasse.298.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.4.mcz
Tests-StephaneDucasse.245.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.495.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/30/2010 23:11'!
script22

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.59.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.1.mcz
Graphics-Display Objects-StephaneDucasse.4.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.4.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.701.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.247.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.2.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.314.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.3.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/13/2010 22:13'!
script220

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.248.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.796.mcz
KernelTests-StephaneDucasse.298.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.4.mcz
Tests-StephaneDucasse.245.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.495.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/13/2010 23:00'!
script221

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.118.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.250.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.798.mcz
KernelTests-StephaneDucasse.298.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.497.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.14.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.4.mcz
Tests-StephaneDucasse.245.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.495.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.384.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/14/2010 23:09'!
script222

	^ 'Announcements-Core-StephaneDucasse.10.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.120.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.252.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.65.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.799.mcz
KernelTests-StephaneDucasse.299.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.498.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.4.mcz
Tests-StephaneDucasse.246.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.496.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.385.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/15/2010 21:49'!
script223

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.120.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.74.mcz
Collections-Strings-MarcusDenker.157.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.49.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.252.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-MarcusDenker.6.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-MarcusDenker.17.mcz
Graphics-Primitives-MarcusDenker.43.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.67.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.799.mcz
KernelTests-StephaneDucasse.299.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.498.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-MarcusDenker.763.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.320.mcz
ST80-MarcusDenker.160.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-MarcusDenker.63.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.4.mcz
Tests-StephaneDucasse.247.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.98.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.496.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.385.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/15/2010 22:19'!
script224

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.121.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.76.mcz
Collections-Strings-StephaneDucasse.159.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.51.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.252.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.8.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-StephaneDucasse.19.mcz
Graphics-Primitives-StephaneDucasse.45.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.67.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.800.mcz
KernelTests-StephaneDucasse.299.mcz
MenuRegistration-StephaneDucasse.25.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.498.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.764.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.321.mcz
ST80-StephaneDucasse.161.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.17.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-StephaneDucasse.64.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.4.mcz
Tests-StephaneDucasse.247.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.99.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.497.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.385.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/17/2010 20:38'!
script225

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.121.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.76.mcz
Collections-Strings-StephaneDucasse.160.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.51.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.252.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.8.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-StephaneDucasse.19.mcz
Graphics-Primitives-StephaneDucasse.45.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.67.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.800.mcz
KernelTests-StephaneDucasse.299.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.498.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.774.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.13.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.330.mcz
ST80-StephaneDucasse.161.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.21.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-StephaneDucasse.84.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.9.mcz
Tests-StephaneDucasse.247.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.99.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.499.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.385.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/17/2010 21:52'!
script226

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.121.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.76.mcz
Collections-Strings-StephaneDucasse.160.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.51.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.252.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.8.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-StephaneDucasse.19.mcz
Graphics-Primitives-StephaneDucasse.45.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.67.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.800.mcz
KernelTests-StephaneDucasse.299.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.498.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.774.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.13.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.331.mcz
ST80-StephaneDucasse.161.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.21.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-StephaneDucasse.84.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.9.mcz
Tests-StephaneDucasse.247.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.99.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.500.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.385.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/18/2010 09:59'!
script227

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.121.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.76.mcz
Collections-Strings-StephaneDucasse.160.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.51.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.252.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.8.mcz
Graphics-Display Objects-MarcusDenker.40.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-StephaneDucasse.19.mcz
Graphics-Primitives-StephaneDucasse.45.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.67.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.800.mcz
KernelTests-StephaneDucasse.299.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.498.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.778.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.13.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.335.mcz
ST80-StephaneDucasse.161.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.21.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-StephaneDucasse.86.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.9.mcz
Tests-StephaneDucasse.247.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.99.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.500.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.385.mcz
TrueType-MarcusDenker.21.mcz
UIManager-MarcusDenker.16.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 11/18/2010 23:02'!
script228

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.122.mcz
Collections-Arrayed-MarcusDenker.58.mcz
Collections-Sequenceable-StephaneDucasse.81.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.76.mcz
Collections-Strings-StephaneDucasse.161.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.52.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-MarcusDenker.490.mcz
Compiler-StephaneDucasse.252.mcz
CompilerTests-MarcusDenker.64.mcz
Compression-StephaneDucasse.74.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.2.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-MarcusDenker.ducasse.189.mcz
Finder-StephaneDucasse.10.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.539.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-StephaneDucasse.9.mcz
Graphics-Display Objects-StephaneDucasse.42.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.16.mcz
Graphics-Fonts-StephaneDucasse.19.mcz
Graphics-Primitives-StephaneDucasse.46.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.8.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.67.mcz
HelpSystem-Tests-StephaneDucasse.15.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.801.mcz
KernelTests-StephaneDucasse.299.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.498.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.81.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.779.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.8.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.13.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.17.mcz
Network-Kernel-MarcusDenker.52.mcz
Network-MIME-MarcusDenker.33.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-StephaneDucasse.27.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.45.mcz
NetworkTests-MarcusDenker.41.mcz
PackageInfo-MarcusDenker.68.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.335.mcz
ST80-StephaneDucasse.161.mcz
SUnit-StephaneDucasse.40118.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-MarcusDenker.13.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.21.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-MarcusDenker.90.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.114.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.206.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-HasBinding.406.mcz
System-Text-StephaneDucasse.87.mcz
System-Tools-StephaneDucasse.39.mcz
System-Undo-StephaneDucasse.9.mcz
Tests-StephaneDucasse.247.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.99.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.501.mcz
ToolsTest-MarcusDenker.denker.11.mcz
Traits-StephaneDucasse.385.mcz
TrueType-MarcusDenker.21.mcz
UIManager-StephaneDucasse.17.mcz
VB-Regex-StephaneDucasse.49.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/1/2010 00:04'!
script23

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.60.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.2.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.5.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-StephaneDucasse.702.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.247.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.3.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.315.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.191.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/2/2010 13:09'!
script24

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.60.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.97.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.2.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.5.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-MarcusDenker.703.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.247.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.3.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.315.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.192.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.78.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 15:54'!
script25

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.60.mcz
Collections-Strings-StephaneDucasse.132.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.2.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.5.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-MarcusDenker.703.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.249.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.3.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.315.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.192.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 16:10'!
script26

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.60.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.4.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.2.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.5.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.54.mcz
Kernel-MarcusDenker.703.mcz
KernelTests-StephaneDucasse.268.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.640.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.249.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.3.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.315.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.192.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.413.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 16:55'!
script27

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.100.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.255.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.705.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.642.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.194.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.415.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 17:22'!
script28

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.100.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.49.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.255.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.4.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.4.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.642.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.137.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.19.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.194.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.415.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/2/2010 19:20'!
script29

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.100.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.643.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.194.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.416.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/12/2010 15:32'!
script3

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.52.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.477.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.28.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.152.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.250.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.39.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-MarcusDenker.689.mcz
KernelTests-MarcusDenker.264.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.620.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.178.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-MarcusDenker.42.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.50.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.32.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-MarcusDenker.35.mcz
NetworkTests-StephaneDucasse.30.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-MarcusDenker.133.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-MarcusDenker.13.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.5.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.68.mcz
System-Clipboard-StephaneDucasse.16.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-MarcusDenker.49.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.97.mcz
System-Platforms-StephaneDucasse.7.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-MarcusDenker.302.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-MarcusDenker.178.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.407.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/3/2010 22:27'!
script30

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.59.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.643.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.416.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/4/2010 23:24'!
script31

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.643.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-StephaneDucasse.250.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.416.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/5/2010 16:07'!
script32

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.155.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-MarcusDenker.644.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.36.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-MarcusDenker.251.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.417.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/6/2010 09:05'!
script33

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.156.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-MarcusDenker.644.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-MarcusDenker.251.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.418.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/6/2010 09:47'!
script34

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.156.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.706.mcz
KernelTests-StephaneDucasse.270.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-MarcusDenker.644.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.1.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.4.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-MarcusDenker.251.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.139.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-StephaneDucasse.6.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.418.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/6/2010 20:39'!
script35

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.156.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.707.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-MarcusDenker.645.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.2.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.252.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.140.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.419.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/7/2010 18:59'!
script36

	^ 'Announcements-Core-StephaneDucasse.4.mcz
Announcements-View-StephaneDucasse.4.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.101.mcz
Collections-Arrayed-StephaneDucasse.49.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.62.mcz
Collections-Strings-StephaneDucasse.134.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.99.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.226.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.156.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.256.mcz
Graphics-Display Objects-StephaneDucasse.5.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.7.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.708.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-MarcusDenker.466.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-MarcusDenker.645.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-MarcusDenker.2.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.21.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.38.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.252.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-MarcusDenker.140.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.100.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.197.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.317.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.195.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.419.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/7/2010 19:14'!
script37

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.257.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.8.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.709.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.646.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.252.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.141.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.318.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/7/2010 23:13'!
script38

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.257.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.8.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.4.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.709.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.646.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.254.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.141.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.318.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2010 00:11'!
script39

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.258.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.709.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.646.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.35.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.254.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.141.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.318.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 16:04'!
script4

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.54.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.30.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.251.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.690.mcz
KernelTests-StephaneDucasse.265.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.621.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.15.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-StephaneDucasse.303.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.179.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2010 15:26'!
script40

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.258.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.709.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.141.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.318.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.21.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/10/2010 18:00'!
script41

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.102.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.258.mcz
Graphics-Display Objects-StephaneDucasse.7.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.37.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.142.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.22.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.196.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/10/2010 18:44'!
script42

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.135.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.142.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.22.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.197.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/11/2010 16:22'!
script43

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.468.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.197.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/11/2010 18:43'!
script44

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.228.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.472.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.647.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.3.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.197.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/11/2010 18:53'!
script45

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.157.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.472.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.62.mcz
Morphic-StephaneDucasse.649.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.57.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.3.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/11/2010 23:08'!
script46

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.649.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.36.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.255.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.3.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.80.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/17/2010 13:39'!
script47

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.51.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.651.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.257.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.3.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.82.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.420.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/17/2010 15:29'!
script48

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.651.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.257.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.82.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/17/2010 16:02'!
script49

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.33.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.653.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.259.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.84.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/12/2010 23:08'!
script5

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.54.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.251.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.690.mcz
KernelTests-StephaneDucasse.265.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.622.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.17.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-StephaneDucasse.306.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.180.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 11:07'!
script50

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.37.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.653.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.259.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.84.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 11:14'!
script51

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.38.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.653.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.259.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.84.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 11:22'!
script52

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.653.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.259.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.84.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 12:12'!
script53

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.655.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.261.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.86.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 12:56'!
script54

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.655.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.261.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.57.mcz
ToolBuilder-Morphic-StephaneDucasse.87.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 13:48'!
script55

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.656.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.262.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 14:24'!
script56

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-MarcusDenker.52.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.710.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.656.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.263.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.421.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 15:25'!
script57

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.711.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.657.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.263.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-MarcusDenker.4.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.422.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2010 17:07'!
script58

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.711.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.64.mcz
Morphic-StephaneDucasse.661.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.422.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/19/2010 22:58'!
script59

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.39.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.259.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.9.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.711.mcz
KernelTests-MarcusDenker.271.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.661.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.321.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.424.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/13/2010 15:09'!
script6

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.54.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.251.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-AdrianLienhard.52.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.691.mcz
KernelTests-StephaneDucasse.266.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.624.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.19.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.191.mcz
System-Support-StephaneDucasse.306.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-AdrianLienhard.15.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.180.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/21/2010 18:12'!
script60

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.712.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.662.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.102.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.425.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/23/2010 12:37'!
script61

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.712.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.662.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.425.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/23/2010 21:22'!
script62

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.532.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.712.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.662.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.426.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/26/2010 12:44'!
script63

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.713.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.662.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.267.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.427.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/27/2010 09:47'!
script64

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.713.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-MarcusDenker.663.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.268.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.427.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/27/2010 15:05'!
script65

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.35.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.160.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.715.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-MarcusDenker.663.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.269.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.88.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.427.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/29/2010 20:46'!
script66

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.161.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.715.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-MarcusDenker.663.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.270.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-IgorStasenko.65.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.89.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.427.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/29/2010 22:05'!
script67

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.138.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.480.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-MarcusDenker.ducasse.161.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-MarcusDenker.715.mcz
KernelTests-StephaneDucasse.272.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.473.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-MarcusDenker.664.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.271.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.322.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.89.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.428.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/31/2010 19:58'!
script68

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.163.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.717.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.66.mcz
Morphic-StephaneDucasse.666.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.271.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.23.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.428.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/1/2010 13:20'!
script69

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.163.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.260.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.6.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.717.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.667.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-MarcusDenker.271.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.199.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.429.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/13/2010 16:10'!
script7

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.53.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.692.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.624.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.21.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.193.mcz
System-Support-StephaneDucasse.306.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.16.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.181.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/1/2010 21:57'!
script70

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.163.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.261.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.56.mcz
Kernel-StephaneDucasse.717.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.667.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.272.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.107.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.203.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.429.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/2/2010 23:16'!
script71

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.165.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.261.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.10.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.6.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.58.mcz
Kernel-StephaneDucasse.717.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.667.mcz
MorphicTests-StephaneDucasse.33.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.108.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.203.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.429.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 14:31'!
script72

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.165.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.533.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.263.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.4.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.58.mcz
Kernel-StephaneDucasse.719.mcz
KernelTests-StephaneDucasse.274.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.670.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.3.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.4.mcz
Network-Kernel-StephaneDucasse.45.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.38.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.324.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.203.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.431.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 15:15'!
script73

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-MarcusDenker.36.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.166.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.534.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.264.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.5.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.59.mcz
Kernel-StephaneDucasse.720.mcz
KernelTests-StephaneDucasse.275.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.5.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.5.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.10.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.325.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.204.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 17:33'!
script74

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.166.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.534.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.264.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.5.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.59.mcz
Kernel-StephaneDucasse.721.mcz
KernelTests-StephaneDucasse.275.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.5.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.5.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.73.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.11.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 18:51'!
script75

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.168.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.534.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.264.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.5.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.59.mcz
Kernel-StephaneDucasse.723.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.5.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.5.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.12.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 19:47'!
script76

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.168.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.534.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.264.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.5.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.59.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.5.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-MarcusDenker.5.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.5.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.12.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/3/2010 23:04'!
script77

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.265.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.671.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.6.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.6.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.13.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.24.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/4/2010 11:57'!
script78

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.265.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.674.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.7.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.7.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.432.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/4/2010 13:06'!
script79

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.265.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.674.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.7.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.7.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.103.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.205.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.434.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/19/2010 12:31'!
script8

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.126.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-AdrianLienhard.223.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.53.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.692.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.626.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.23.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.193.mcz
System-Support-StephaneDucasse.307.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.187.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/5/2010 15:29'!
script80

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.230.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.265.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.12.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.476.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-MarcusDenker.675.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.7.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.7.mcz
Network-Kernel-StephaneDucasse.46.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.327.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.206.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.434.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/8/2010 18:49'!
script81

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.266.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.13.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.477.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.676.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.7.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-StephaneDucasse.4.mcz
Multilingual-TextConversion-StephaneDucasse.7.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-StephaneDucasse.33.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.328.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.206.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.434.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/9/2010 17:09'!
script82

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.266.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.13.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.477.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.676.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-MarcusDenker.11.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.10.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.35.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.273.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.328.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.206.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.434.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/10/2010 21:41'!
script83

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.266.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.13.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.277.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.477.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.676.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.13.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.35.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.274.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.328.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.206.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.435.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/10/2010 22:33'!
script84

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.63.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.169.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.266.mcz
Graphics-Display Objects-StephaneDucasse.8.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.13.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.724.mcz
KernelTests-StephaneDucasse.278.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.477.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.67.mcz
Morphic-StephaneDucasse.678.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.13.mcz
Multilingual-Display-StephaneDucasse.4.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.35.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.75.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.8.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.330.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.207.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.435.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.18.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/11/2010 12:50'!
script85

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-StephaneDucasse.103.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-StephaneDucasse.141.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.100.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-StephaneDucasse.40.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.267.mcz
Graphics-Display Objects-StephaneDucasse.9.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.726.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-StephaneDucasse.679.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.35.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.66.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-StephaneDucasse.3.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.330.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-StephaneDucasse.207.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-StephaneDucasse.91.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.436.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-StephaneDucasse.376.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/14/2010 23:12'!
script86

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.104.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.142.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.482.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-MarcusDenker.41.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.268.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.727.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.680.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.437.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.377.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/15/2010 11:10'!
script87

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-StephaneDucasse.54.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-StephaneDucasse.55.mcz
DeprecatedPreferences-MarcusDenker.41.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.268.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-StephaneDucasse.6.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.727.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.37.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.438.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.377.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/15/2010 13:01'!
script88

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.42.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.269.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.7.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.727.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.438.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.377.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/15/2010 13:41'!
script89

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.727.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.276.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.438.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.377.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/21/2010 22:40'!
script9

	^ 'Announcements-adrian_lienhard.22.mcz
Balloon-StephaneDucasse.49.mcz
Collections-Abstract-StephaneDucasse.98.mcz
Collections-Arrayed-StephaneDucasse.48.mcz
Collections-Sequenceable-StephaneDucasse.74.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.55.mcz
Collections-Strings-StephaneDucasse.127.mcz
Collections-Support-StephaneDucasse.35.mcz
Collections-Text-StephaneDucasse.33.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-StephaneDucasse.95.mcz
Collections-Weak-StephaneDucasse.44.mcz
CollectionsTests-StephaneDucasse.478.mcz
Compiler-StephaneDucasse.225.mcz
CompilerTests-StephaneDucasse.48.mcz
Compression-StephaneDucasse.61.mcz
DeprecatedPreferences-StephaneDucasse.31.mcz
Exceptions-MarcusDenker.58.mcz
Files-StephaneDucasse.ducasse.154.mcz
FixUnderscores-stephane_ducasse.17.mcz
FreeType-StephaneDucasse.530.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.125.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.252.mcz
GraphicsResources-AdrianLienhard.10.mcz
GraphicsTests-StephaneDucasse.41.mcz
HelpSystem-Core-StephaneDucasse.53.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-AdrianLienhard.52.mcz
Kernel-StephaneDucasse.694.mcz
KernelTests-StephaneDucasse.267.mcz
MenuRegistration-AdrianLienhard.23.mcz
Monticello-MarcusDenker.464.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.61.mcz
Morphic-StephaneDucasse.626.mcz
MorphicTests-StephaneDucasse.30.mcz
Multilingual-StephaneDucasse.179.mcz
MultilingualTests-MarcusDenker.20.mcz
Network-Kernel-StephaneDucasse.43.mcz
Network-MIME-MarcusDenker.17.mcz
Network-MailSending-MarcusDenker.9.mcz
Network-Protocols-StephaneDucasse.52.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.34.mcz
Network-URI-StephaneDucasse.22.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.36.mcz
NetworkTests-StephaneDucasse.32.mcz
PackageInfo-StephaneDucasse.55.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.33.mcz
Polymorph-Tools-Diff-StephaneDucasse.35.mcz
Polymorph-Widgets-AdrianLienhard.244.mcz
PreferenceBrowser-MarcusDenker.63.mcz
ST80-StephaneDucasse.134.mcz
SUnit-AdrianLienhard.105.mcz
SUnitGUI-IgorStasenko.65.mcz
ScriptLoader12-StephaneDucasse.25.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.14.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.71.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Digital Signatures-MarcusDenker.14.mcz
System-Download-StephaneDucasse.51.mcz
System-FilePackage-StephaneDucasse.47.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-Hashing-StephaneDucasse.8.mcz
System-Localization-StephaneDucasse.53.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-StephaneDucasse.99.mcz
System-Platforms-StephaneDucasse.9.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.193.mcz
System-Support-StephaneDucasse.308.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.18.mcz
System-Tools-MarcusDenker.34.mcz
Tests-StephaneDucasse.187.mcz
ToolBuilder-Kernel-StephaneDucasse.51.mcz
ToolBuilder-Morphic-stephaneDucasse.75.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.408.mcz
ToolsTest-StephaneDucasse.denker.8.mcz
Traits-MarcusDenker.374.mcz
TrueType-StephaneDucasse.18.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/15/2010 19:18'!
script90

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-StephaneDucasse.65.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.728.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.36.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-MarcusDenker.277.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.439.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.378.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/16/2010 09:12'!
script91

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.729.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.70.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-MarcusDenker.277.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.378.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/16/2010 15:32'!
script92

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.730.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.71.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-MarcusDenker.277.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.331.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'stephaneducasse 8/16/2010 23:24'!
script93

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.71.mcz
Morphic-MarcusDenker.681.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-MarcusDenker.277.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneducasse.332.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/17/2010 20:12'!
script94

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.71.mcz
Morphic-StephaneDucasse.683.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.279.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneducasse.332.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/18/2010 11:42'!
script95

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.684.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.279.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneducasse.332.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.26.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/19/2010 11:23'!
script96

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-MarcusDenker.483.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-MarcusDenker.270.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.7.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.684.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.280.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-stephaneducasse.332.mcz
System-Tests-ChangeNotification-StephaneDucasse.2.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/19/2010 22:39'!
script97

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-StephaneDucasse.232.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.685.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.55.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-StephaneDucasse.3.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.333.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/20/2010 11:55'!
script98

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-MarcusDenker.233.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-MarcusDenker.686.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.14.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.4.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.6.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.12.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.333.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/20/2010 22:30'!
script99

	^ 'Announcements-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.51.mcz
Collections-Abstract-MarcusDenker.105.mcz
Collections-Arrayed-StephaneDucasse.51.mcz
Collections-Sequenceable-StephaneDucasse.76.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.63.mcz
Collections-Strings-MarcusDenker.143.mcz
Collections-Support-StephaneDucasse.37.mcz
Collections-Text-StephaneDucasse.38.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.101.mcz
Collections-Weak-StephaneDucasse.46.mcz
CollectionsTests-StephaneDucasse.484.mcz
Compiler-MarcusDenker.233.mcz
CompilerTests-MarcusDenker.55.mcz
Compression-MarcusDenker.67.mcz
ConfigurationOfGofer-StephaneDucasse.15.mcz
ConfigurationOfMetacello-StephaneDucasse.332.mcz
ConfigurationOfOmniBrowser-MarcusDenker.56.mcz
Deprecated12-MarcusDenker.1.mcz
DeprecatedPreferences-MarcusDenker.43.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-StephaneDucasse.61.mcz
Files-StephaneDucasse.ducasse.170.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.535.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.127.mcz
Gofer-Tests-MarcusDenker.124.mcz
Graphics-StephaneDucasse.271.mcz
Graphics-Display Objects-MarcusDenker.10.mcz
Graphics-External-StephaneDucasse.6.mcz
Graphics-Files-StephaneDucasse.4.mcz
Graphics-Fonts-StephaneDucasse.8.mcz
Graphics-Primitives-StephaneDucasse.14.mcz
Graphics-Resources-StephaneDucasse.4.mcz
Graphics-Support-StephaneDucasse.4.mcz
Graphics-Tests-StephaneDucasse.8.mcz
Graphics-Text-MarcusDenker.8.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.58.mcz
HelpSystem-Tests-StephaneDucasse.13.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-stephaneducasse.731.mcz
KernelTests-StephaneDucasse.279.mcz
MenuRegistration-AdrianLienhard.23.mcz
MimeConverter-StephaneDucasse.4.mcz
Monticello-StephaneDucasse.479.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.72.mcz
Morphic-StephaneDucasse.687.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-StephaneDucasse.15.mcz
Multilingual-Display-StephaneDucasse.5.mcz
Multilingual-Encodings-StephaneDucasse.6.mcz
Multilingual-ImmPlugin-StephaneDucasse.4.mcz
Multilingual-Languages-StephaneDucasse.8.mcz
Multilingual-Scanning-StephaneDucasse.4.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.14.mcz
Network-Kernel-StephaneDucasse.47.mcz
Network-MIME-StephaneDucasse.23.mcz
Network-MailSending-StephaneDucasse.10.mcz
Network-Protocols-StephaneDucasse.54.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.39.mcz
Network-URI-StephaneDucasse.24.mcz
Network-UUID-StephaneDucasse.15.mcz
Network-Url-StephaneDucasse.39.mcz
NetworkTests-MarcusDenker.37.mcz
PackageInfo-StephaneDucasse.59.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.3.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-MarcusDenker.38.mcz
Polymorph-Widgets-StephaneDucasse.281.mcz
Polymorph-Widgets-Themes-Additions-StephaneDucasse.1.mcz
ST80-StephaneDucasse.143.mcz
SUnit-StephaneDucasse.109.mcz
SUnitGUI-MarcusDenker.67.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.2.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.5.mcz
Settings-Polymorph-StephaneDucasse.8.mcz
Settings-System-StephaneDucasse.8.mcz
Settings-Tools-StephaneDucasse.7.mcz
System-Applications-StephaneDucasse.18.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-marcus_denker.9.mcz
System-Changes-StephaneDucasse.76.mcz
System-Clipboard-StephaneDucasse.18.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-MarcusDenker.56.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.9.mcz
System-Finalization-StephaneDucasse.13.mcz
System-GUISupport-StephaneDucasse.3.mcz
System-Hashing-StephaneDucasse.11.mcz
System-Installers-StephaneDucasse.9.mcz
System-Launcher-MarcusDenker.4.mcz
System-Localization-StephaneDucasse.54.mcz
System-Object Events-StephaneDucasse.6.mcz
System-Object Storage-MarcusDenker.104.mcz
System-Platforms-StephaneDucasse.14.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.199.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.334.mcz
System-Tests-ChangeNotification-StephaneDucasse.3.mcz
System-Text-StephaneDucasse.27.mcz
System-Tools-StephaneDucasse.37.mcz
Tests-MarcusDenker.208.mcz
ToolBuilder-Kernel-StephaneDucasse.58.mcz
ToolBuilder-Morphic-MarcusDenker.92.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.440.mcz
ToolsTest-StephaneDucasse.denker.10.mcz
Traits-MarcusDenker.379.mcz
TrueType-StephaneDucasse.20.mcz
UIManager-StephaneDucasse.4.mcz
VB-Regex-AdrianLienhard.48.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/13/2010 22:30'!
setToRepositoriesPassword: aPassword to: aUser
	"self new setToRepositoriesPassword: 'sd' to: 'zork'"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllHTTPRepositories: {self repository locationWithTrailingSlash . self inboxRepository locationWithTrailingSlash}. 
	self repository password: aPassword.
	self repository user: aUser.
	self inboxRepository password: aPassword.
	self inboxRepository user: aUser.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:07'!
setUpdateAndScriptVersionNumbers
	CurrentUpdateVersionNumber := self getLatestUpdateNumber + 1.
	CurrentScriptVersionNumber := self getLatestScriptNumber + 1.! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 11/8/2010 22:09'!
shortImageName
	"should be removed when the version  will be integrated in SmalltalkImage"
	
	^ FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName).! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 11/13/2010 22:21'!
theScriptLoaderPackageName
	^'ScriptLoader',  CurrentMajorVersionNumber asString copyWithout: $. ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:58'!
unloadPackage: aString
	"self new unloadPackage: 'Sixx'"
	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	toRemove unload.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'stephane.ducasse 2/6/2009 17:36'!
unloadPackageNamed: aString
	"self new workingCopyFromPackageName: 'CollectionExtensions' "
	
	^ (self workingCopyFromPackageName: aString) unload
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 7/15/2006 20:39'!
unloadPackages
	"ScriptLoader new unloadPackages"
	
	| copies namesOfpackagesToUnload |
	namesOfpackagesToUnload := self packagesToUnload. 
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	(copies select: [:each | namesOfpackagesToUnload anySatisfy: [:ea | ea match: each package name ]])
		do: [:z | z unload].! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 13:09'!
update11202

	"place holder"! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 13:21'!
update12002

	"place holder"! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 13:35'!
update12003
	"self new update12003"
	self withUpdateLog: 'Issue 2503:	Remove add viewing'.
	self loadTogether: self script1 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 15:16'!
update12004
	"self new update12004"
	self withUpdateLog: '- ScriptLoaderTest fixes
- Issue 2487: Morph cleaning
- Issue 2455: testIsAllDigits'.
	self loadTogether: self script2 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/12/2010 15:32'!
update12005
	"self new update12005"
	self withUpdateLog: 'Redo the changes of 11400:
Issue 2548:	NewTestMorphTests>>#testAcceptContents fails
Issue 2547:	FilesStreamTest>>testPositionPastEndIsAtEnd
Issue 2506:	Browsing hierarchy of Traits crashes OB'.
	self loadTogether: self script3 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 16:04'!
update12006
	"self new update12006"
	self withUpdateLog: '- Issue 1795:	look for squeak everywhere. Thanks Veronica'.
	self loadTogether: self script4 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/12/2010 23:08'!
update12007
	"self new update12007"
	self withUpdateLog: '- Issue 2290: new windows (e.g. workspaces) appear wherever they feel like
- SystemChangeNotifier-Tests from 3.9. 
- Issue 2381: We should probably remove slideToTrash'.
	self loadTogether: self script5 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/13/2010 15:09'!
update12008
	"self new update12008"
	self withUpdateLog: '- 2990: fix a bug which make selection of strategy does not work. --> this is an old code for testing, which I lost.

2422 Removed
- isolationSet and thisDefinition (instances variables never used) 
- methods reassigning isolationSet also removed (as it was never initialized)

- TestSubclass '.
	self loadTogether: self script6 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/13/2010 16:11'!
update12009
	"self new update12009"
	self withUpdateLog: 'Partial cleanup for 2204 
Rewrite plenty of Smalltalk at:  as Smalltalk globals at: '.
	self loadTogether: self script7 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/19/2010 12:32'!
update12010
	"self new update12010"
	self withUpdateLog: '- Issue 2556:	AutoStart
- Issue 2557:	NewTextMorph and CodeMorphs refactorings and tests'.
	self loadTogether: self script8 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/21/2010 22:40'!
update12011
	"self new update12011"
	self withUpdateLog: '- Issue 2555:	WideString asByteString does not return a ByteString. Thanks Henrik!!
- Issue 2580: COG	primitive:error: pragma does not work. Thanks Eliot/Henrik
- Issue 2581: COG	Float access methods
- Issue 2579:	Necessary Image Changes For Cog To Work
	'.
	self loadTogether: self script9 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/22/2010 18:46'!
update12012
	"self new update12012"
	self withUpdateLog: '- Issue 2582:	Rearrange World Menu
- Issue 2069:	Be able to load DummyUIManager in a Pharo image'.
	self loadTogether: self script10 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 18:20'!
update12013
	"self new update12012"
	"placeholder to rsync with the update"! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 18:36'!
update12014
	"self new update12014"
	self withUpdateLog: '- Issue 2582:	Rearrange World Menu'.
	self loadTogether: self script11 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 20:25'!
update12015
	"self new update12015"
	self withUpdateLog: '- Issue 2554:	SystemWindow>>embeddable defect. Thanks Hilaire
- Issue 2547:	FilesStreamTest>>testPositionPastEndIsAtEnd	
- Issue 2546:	Tests failing: BlockClosureTest and MessageTallyTest'.
	self loadTogether: self script12 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 21:04'!
update12016
	"self new update12016"
	self withUpdateLog: '- Issue 2413:	cmd-b and cmd-m with fallbacks
- Issue 2069:	Be able to load DummyUIManager in a Pharo image	
- Issue 2528:	test commenting and cleaning'.
	self loadTogether: self script13 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/26/2010 22:53'!
update12017
	"self new update12017"
	self withUpdateLog: '- Issue 2585:	Missing menus in Mac host menu. Thanks Laurent
- Issue 2576:	Adding auto fit to NewTextMorph (new version). Thanks Fernando
- Issue 2589:	TestCase >> should: notTakeMoreThan: not working well with asserts in block
	Changes should: notTakeMoreThan: so the evaluated block if it raises exceptions does not cause a timeout assertion failure, but rather a failure appropriate for the exception which occurred.
This means such errors no longer causes opening of debuggers when running a test batch, and that when selecting the failed test, the debugger opens on the relevant failure. Thanks Henrik.'.
	self loadTogether: self script14 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/27/2010 18:24'!
update12018
	"self new update12018"
	self withUpdateLog: '-  Issue 2593:	SystemNavigation#allSendersOf: returns inexisting references
	
- Issue 2480:	make and:and:and:and: and and:and: deprecated'.
	self loadTogether: self script15 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/27/2010 22:15'!
update12019
	"self new update12019"
	self withUpdateLog: '- Issue 156: Pointer tracing tools do not consistently find pointers. Thanks andy, johan and matthew.'.
	self loadTogether: self script16 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/28/2010 15:28'!
update12020
	"self new update12020"
	self withUpdateLog: '- Issue-2448-WideStringDisplayMangled. Part one'.
	self loadTogether: self script17 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/28/2010 15:49'!
update12021
	"self new update12021"
	self withUpdateLog: 'Issue-2448-WideStringDisplayMangled. Part Two of slice, now with inst var in super, and refactored methods.
Part ONE (ie version 3) needs to be loaded before this one.
(ie. this is needs two separate patches)'.
	self loadTogether: self script18 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/28/2010 16:42'!
update12022
	"self new update12022"
	self withUpdateLog: '-  Issue 2597:	Versions Browser diff checkboxes'.
	self loadTogether: self script19 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/28/2010 20:08'!
update12023
	"self new update12023"
	self withUpdateLog: '- Issue 2577:	Duplicate primInitializeNetwork: method'.
	self loadTogether: self script20 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/30/2010 21:41'!
update12024
	"self new update12024"
	self withUpdateLog: '- Issue 2105:	Packages remodularization'.
	self loadTogether: self script21 merge: false.
	(MCPackage named: 'Announcements') workingCopy unregister.
(MCPackage named: 'Graphics') workingCopy unregister.
(MCPackage named: 'GraphicsTests') workingCopy unregister.
(MCPackage named: 'GraphicsResources') workingCopy unregister.
(MCPackage named: 'Multilingual') workingCopy unregister.
(MCPackage named: 'MultilingualTests') workingCopy unregister.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/30/2010 23:11'!
update12025
	"self new update12025"
	self withUpdateLog: '- Issue 2599:	better extract parameter
- Issue 2604:	a script as argument
       squeak mysqueak.image file.st
       squeak mysqueak.image scripts/file.st
       squeak mysqueak.image ../../svn/scripts/file.st'.
	self loadTogether: self script22 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/1/2010 00:04'!
update12026
	"self new update12026"
	self withUpdateLog: '- Issue 2069:	Be able to load DummyUIManager in a Pharo image. Part two'.
	self loadTogether: self script23 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/2/2010 13:09'!
update12027
	"self new update12027"
	self withUpdateLog: 'Issue 2612:	DateAndTime current asUnixTime walkback in 1.1 rc3
Issue 2588:	Dictionary>>do:
Issue 2598:	Trait composition with exclusion lost when loading package from MC'.
	self loadTogether: self script24 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 15:54'!
update12028
	"self new update12028"
	self withUpdateLog: '- Issue 2615:	Use overflow rows for ToolBuilder button panels. Thanks Gary!!
- Issue 2616:	Use overflow rows for Debugger custom buttons.
Thanks Gary!!
-  Issue 2624:	Much faster Dictionary>>unreferencedKeys. Thanks Eliot'.
	self loadTogether: self script25 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 16:10'!
update12029
	"self new update12029"
	self withUpdateLog: '- Issue 2625:	Symbol class>>selectorsContaining:. Thanks Eliot'.
	self loadTogether: self script26 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 16:55'!
update12030
	"self new update12030"
	self withUpdateLog: '- Issue 2596:	More cull: usage. Thanks henrik'.
	self loadTogether: self script27 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 17:22'!
update12031
	"self new update12031"
	self withUpdateLog: '- Issue 2307:	Block should display their code
- Issue 2584:	COG- LargeNegativeInteger to be compact at 5'.
	self loadTogether: self script28 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/2/2010 19:20'!
update12032
	"self new update12032"
	self withUpdateLog: '- Issue 2613:	remove PopUpMenu SelectionMenu CustomMenu'.
	self loadTogether: self script29 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/3/2010 22:27'!
update12033
	"self new update12033"
	self withUpdateLog: '- Issue 2636:	Collection>>ifNotEmpty: and ifEmpty: better comment and more explitcit definition
- Issue 2483: test to check that temp are nil out'.
	self loadTogether: self script30 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/4/2010 23:25'!
update12034
	"self new update12034"
	self withUpdateLog: '-  Issue 2638:	DNU does not open a debugger. 
Thanks pavel :) We are allowed to break the system to improve it ok after we have to help to repair it :)'.
	self loadTogether: self script31 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/5/2010 16:07'!
update12035
	"self new update12035"
	self withUpdateLog: 'Issue 2639:	Tidy up of MessageNames tool
Issue 1498:	FileList will not allow you to delete a directory?'.
	self loadTogether: self script32 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/6/2010 09:05'!
update12036
	"self new update12036"
	self withUpdateLog: 'Issue 2640:	Adding remote server uses deprected API
Issue 2641:	File already exists dialog has a missing space
Issue 2643:	Read ftp file with remote server using FileList crashes with DNU
Issue 2642:	Improve the PopupChoiceDialogWindow/PopupChoiceOrRequestDialogWindow'.
	self loadTogether: self script33 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/6/2010 09:48'!
update12037
	"self new update12037"
	self withUpdateLog: 'Issue 2590:	Remove PreferenceBrowser package
Issue 2645:	Remove System Package'.
	self loadTogether: self script34 merge: false.
	(MCPackage named: 'System') workingCopy unregister.
(MCPackage named: 'PreferenceBrowser') workingCopy unregister
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/6/2010 20:41'!
update12038
	"self new update12038"
	self withUpdateLog: 'Issue 2648:	LanguageEnvironment>>setupSqueaklandSpecifics
Issue 2647:	Consistency by providing uppercase menu items in Tools menus
Issue 2649:	World tasklist navigation
Issue 2644:	DateAndTime>>asUnixTime should ignore timezones?'.
	self loadTogether: self script35 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/7/2010 19:00'!
update12039
	"self new update12039"
	self withUpdateLog: 'Issue 2635: Preparation. '.
	self loadTogether: self script36 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/7/2010 19:15'!
update12040
	"self new update12040"
	self withUpdateLog: 'Issue 2635: Uppercase extensions - first mail. '.
	self loadTogether: self script37 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/7/2010 23:13'!
update12041
	"self new update12041"
	self withUpdateLog: '- Issue 2642:	Improve the PopupChoiceDialogWindow/PopupChoiceOrRequestDialogWindow'.
	self loadTogether: self script38 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2010 00:12'!
update12042
	"self new update12042"
	self withUpdateLog: '- Issue 2657:	some Point enhancements'.
	self loadTogether: self script39 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2010 15:26'!
update12043
	"self new update12043"
	self withUpdateLog: '- Issue 2595:	Changing color/fillStyle by morph halo menu'.
	self loadTogether: self script40 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/10/2010 18:00'!
update12044
	"self new update12044"
	self withUpdateLog: '- Issue 2652:	better flush of class name cache when removing key
- Issue 2568:	Remove ancient j3 support	
- Issue 2650:	Easier doit of commented expresson'.
	self loadTogether: self script41 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/10/2010 18:44'!
update12045
	"self new update12045"
	self withUpdateLog: '- Issue 2300:	ServerDirectory cleanup	
- Issue 2226:	shuffled and shuffle
- Issue 2238:	tests for FileStream behavior.
- Issue 2129:	Cursor with Alpha from OLPC
	CursorWithAlpha biggerNormal showWhile:[Sensor waitButton]. '.
	self loadTogether: self script42 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/11/2010 16:49'!
update12046
	"self new update12046"
	self withUpdateLog: '- Issue 2665:	Fixed broken string in selection evaluation.
- Add System-Installers as package (empty but code is coming)'.
	self loadTogether: self script43 merge: false.
	self addPackage: 'System-Installers'.
self removeAllRepositories.
self addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/11/2010 18:43'!
update12047
	"self new update12047"
	self withUpdateLog: 'Issue 2664:	Lost some classes only sarInstaller and MczInstaller'.
	self loadTogether: self script44 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/11/2010 18:54'!
update12048
	"self new update12048"
	self withUpdateLog: '- Issue 2664: empty classes: WebBrowser, SketchMorph, PasteUpMorphTest, NameOfSubclass, MethodTempsNode'.
	self loadTogether: self script45 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/11/2010 23:10'!
update12049
	"self new update12049"
	self withUpdateLog: '- Issue 2501: Refactored directory scanning
- PackageOrganizer enh
- Issue 2623: Make sure MCWorkingCopy receives system change notifications by reregistering for them on startup.'.
	self loadTogether: self script46 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/17/2010 13:41'!
update12050
	"self new update12050"
	self withUpdateLog: '- Issue 2671:	SelectedObjectThumbnail should be removed
- Issue 2669:	ProgressMorph should be removed
- Issue 2675:	Push everything from PSUIManager to MorphicUIManager'.
	self loadTogether: self script47 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/17/2010 15:29'!
update12051
	"self new update12051"
	self withUpdateLog: 'Issue 2201:	SarInstaller refers to SqueakMap
Issue 2680:	Renaming a key in a dictionary and cancelling renames the key to nil'.
	self loadTogether: self script48 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/17/2010 16:02'!
update12052
	"self new update12052"
	self withUpdateLog: '- Issue 2676: PluggableTextMorphPlusRemoval'.
	self loadTogether: self script49 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 11:08'!
update12053
	"self new update12053"
	self withUpdateLog: 'preparing unload of preferences'.
	self loadTogether: self script50 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 11:14'!
update12054
	"self new update12054"
	self withUpdateLog: 'preparing unload of preferences 2'.
	self loadTogether: self script51 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 11:23'!
update12055
	"self new update12055"
	self withUpdateLog: 'Remove PreferenceBrowser'.
	self loadTogether: self script52 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 12:12'!
update12056
	"self new update12056"
	self withUpdateLog: 'Issue 2676 - Remove PluggableListMorphPlus'.
	self loadTogether: self script53 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 12:56'!
update12057
	"self new update12057"
	self withUpdateLog: 'Issue 2676 - Really removing the classes PluggableListMorphPlus'.
	self loadTogether: self script54 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 13:48'!
update12058
	"self new update12058"
	self withUpdateLog: 'Issue 2676 - remove PluggableButtonMorphPlus'.
	self loadTogether: self script55 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 14:25'!
update12059
	"self new update12059"
	self withUpdateLog: 'Issue 2676 - remove PluggableButtonMorphPlus reference'.
	self loadTogether: self script56 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 15:25'!
update12060
	"self new update12060"
	self withUpdateLog: 'Large cleaning of PasteUpMorph underway'.
	self loadTogether: self script57 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2010 17:07'!
update12061
	"self new update12061"
	self withUpdateLog: 'removing donor and partBin'.
	self loadTogether: self script58 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/19/2010 22:58'!
update12062
	"self new update12062"
	SystemChangeNotifier uniqueInstance notify: Smalltalk ofAllSystemChangesUsing: #event:.
	self withUpdateLog: '- Issue 2694:	MC screwing up ancestry
- Issue 2684:	Deleting a method is not logged	
		SystemChangeNotifier uniqueInstance notify: Smalltalk ofAllSystemChangesUsing: #event:.
-  Issue 2681:	easily browse the variables defined in a workspace'.
	self loadTogether: self script59 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/21/2010 18:15'!
update12063
	"self new update12063"
	self withUpdateLog: '- Issue 2708:	Cleaning a bit systemnavigation.
- Issue 2701:	fix duplicate entries handling in recentmessageset	. Thanks benjamin
- Issue 2702:	Better duller from Squeak.
- Issue 2689:	random morph unused code cleanups
-  Issue 2699:	Hex for Cog
'.
	self loadTogether: self script60 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/23/2010 12:38'!
update12064
	"self new update12064"
	self withUpdateLog: '- Issue 2711:	SmartRefStream (and hence also ImageSegment) are broken due to missing #convertToCurrentVersion:refStream:'.
	self loadTogether: self script61 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/23/2010 21:24'!
update12065
	"self new update12065"
	self withUpdateLog: '- Issue 2654:	ChangeList ENH from eliot. '.
	self loadTogether: self script62 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/26/2010 12:44'!
update12066
	"self new update12066"
	self withUpdateLog: 'Issue 2712:	Once
Issue 2715:	remove three methods from Object: evaluateUnloggedForSelf, stringRepresentation, stringForReadout
Issue 2529:	FreeTypeFont>>veryDeepCopyWith:
'.
	self loadTogether: self script63 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/27/2010 09:47'!
update12067
	"self new update12067"
	self withUpdateLog: 'Issue 670:	should clean Morph menu
Issue 2716:	New graphics for mouse over on window controls'.
	self loadTogether: self script64 merge: false.
	UITheme current class beCurrent.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/27/2010 15:05'!
update12068
	"self new update12068"
	self withUpdateLog: 'Issue 2719:	CachedBlockClosure >> value should uncache block
Issue 2695:	Tasklist on Mac'.
	self loadTogether: self script65 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/29/2010 20:46'!
update12069
	"self new update12069"
	self withUpdateLog: 'Issue 1699:	A File out of existing code aborts when canceled
Issue 2722:	Fix some Undeclared References in 12068
Issue 2700:	Bug opening TestRunner in 12062 and 12061'.
	self loadTogether: self script66 merge: false.
	Compiler recompileAll.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/29/2010 22:05'!
update12070
	"self new update12070"
	self withUpdateLog: 'Issue 2723:	TestRunner UI does not provide fly by help for buttons
Issue 2724:	Window button fly by help should start with uppercase
Issue 2725:	Debugger context menu items do not start with uppercase letter
Issue 2726:	Fly by help of debugger buttons should start with uppercase'.
	self loadTogether: self script67 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/31/2010 19:58'!
update12071
	"self new update12071"
	self withUpdateLog: '- Issue 2732:	Paste Up Clean up post actions required
- Issue 2731:	SystemNavigation cleaning
- Issue 2730:	Dialog cleaning
- Issue 2728:	MCSubDirectoryRepository should not use / but
- Issue 2709:	printStringHex for Character'.
	self loadTogether: self script68 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/1/2010 13:21'!
update12072
	"self new update12072"
	self withUpdateLog: '- Issue 2727:	Consistency by providing uppercase menu items in Tools menus (Part 2). Thanks Torsten. There are no such little fixes :)'.
	self loadTogether: self script69 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/1/2010 22:07'!
update12073
	"self new update12073"
	self withUpdateLog: '- Issue 1289:	Changing locale raises DNU
- test categories cleaning. Thanks alexandre.
- Issue 2205:	pluggable Tree Morph deselect behavior. Tx Laurent.'.
	self loadTogether: self script70 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/2/2010 23:40'!
update12074
	"self new update12074"
	self withUpdateLog: '- Issue 2169:	FileDirectory>>matchingEntries: criteria is broken. Thanks CarloTeixeira.
	
-  Issue 2738:	Browse instance/?/class button should provide fly by help. Thanks Torsten Bergmann.
	
- Issue 1068:	Mac: Quit from host menu not working anymore. Thanks Mike Roberts.
	
- Issue 2721:	Extending SUnit to emit announcement. Thanks Alexandre Bergel'.
	self loadTogether: self script71 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 14:31'!
update12075
	"self new update12075"
	self withUpdateLog: '- Issue 2296: Point>>closeTo. Thanks Alexandre Bergel and Henrik Johanssen.

- SUnit Announcement post fix.

- Issue 2617:	Fix restart in blocks in debugger. Thanks Henrik Johanssen.
	
-  Issue 2364:	FileList menu more... is bogus. Thanks Carlo Teixeira
	
-  Issue 1767:	Method Finder gives UndefinedObject error on search. Thanks Alexandre Bergel. Thanks Marcus, patchinko and  Gary.'.
	self loadTogether: self script72 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 15:51'!
update12076
	"self new update12076"
	self withUpdateLog: '- Issue 2347:	Migrating some OS queries from SmalltalkImage to OSPlatform. This changes is really nice since it used the existing Platform classes for that they should. 
	Now do you use Smalltalk os, Smalltalk platform but 
	OSPlatform os
	OSPlatform platform
This way OSPlatform is used for what it should. It would be nice if Squeak would follow this change, else we will add a compatibility package. Thanks Simon Denier.'.
	self loadTogether: self script73 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 17:36'!
update12077
	"self new update12077"
	self withUpdateLog: '- Issue 2347:  fixing Problem with previous release vmVersion was missing. 
- Issue 2745: Text>>fromString; , does not add by default a (TextColor color: Color black ) attribute. Thanks Fernando Olivero.

- Issue 2662:	value: primitives. Thanks Eliot Miranda, Henrik Johanssen.

- Issue 2603:	isRunningCog. Thanks Andreas Raab, German Arduino.
	
- Issue 2609:	getSystemAttribute: 2 -> documentPath. Thanks German Arduino.'.
	self loadTogether: self script74 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 18:52'!
update12078
	"self new update12078"
	self withUpdateLog: '- Issue 2661: File name correction for unix to allow. Thanks Eliot Miranda, German Ardino.

- Issue 2122:	superclassOrder: is defined on Changeset. Now defined on Class. Thanks Steven Freeman.
	
- Fixed OSPlatform vmVersion'.
	self loadTogether: self script75 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 19:47'!
update12079
	"self new update12079"
	self withUpdateLog: '- Issue 2655:	Fix the other dependencies of asContextWithSender:'.
	self loadTogether: self script76 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/3/2010 23:10'!
update12080
	"self new update12080"
	self withUpdateLog: '- Issue 1298:	CrLfFileStream not properly initialized on Mac OS. Thanks Andrew Black and Carlo Teixeira	'.
	self loadTogether: self script77 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/4/2010 11:58'!
update12081
	"self new update12081"
	self withUpdateLog: '- Fixing vmVersion comments and guessDefaultEndline

- Issue 2746: NewTextMorph now uses theme text adornments
Polymorph text addornment and other minor refactorings to NewTextMorph and related classes. Thanks Fernando Olivero

-  Issue 2749:	NewTextMorph does not react to enter and escape keystrokes. Thanks Fernando Olivero'.
	self loadTogether: self script78 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/4/2010 13:07'!
update12082
	"self new update12082"
	self withUpdateLog: '- Issue 2751:	Recover last changes broken'.
	self loadTogether: self script79 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/5/2010 15:29'!
update12083
	"self new update12083"
	self withUpdateLog: 'Issue 2749:	NewTextMorph does not react to enter and escape keystrokes (part 2)
Issue 2750:	Loading an image segment can introduce a class named AnObsoleteFake37SomeName'.
	self loadTogether: self script80 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/8/2010 18:54'!
update12084
	"self new update12084"
	self withUpdateLog: '-  Issue 2760:	More robust handling of HTTP upload responses. Thanks Andreas Raab.
	
-  Issue 2753:	introduce Smalltalk  platform to forward to OSPlatform.
	
- Issue 2761:	Some Cog-specific VM attribute accessors
	
- Issue 2763:	SocketStream destroy. Thanks Andreas Raab.
	
- Better xIllegal message. Thanks Nicolas Cellier

- Better Rectangle class comment. Thanks Nicolas Cellier
'.
	self loadTogether: self script81 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/9/2010 17:09'!
update12085
	"self new update12085"
	self withUpdateLog: 'Issue 2774:	UTF16TextConverter incorrectly writes/does not write BOMs in different circumstances
Issue 2765:	SocketStreamTest are green in Squeak and hang on Pharo (add test)'.
	self loadTogether: self script82 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/10/2010 21:42'!
update12086
	"self new update12086"
	self withUpdateLog: '- Issue 2752: Metacello configuration browser. Thanks Torsten Bergmann.
- Issue 2776: UTF16TextConverter write speedup. Thanks Henrik Johanssen.
- Issue 2777:	Polymorph enhancements. Thanks Gary Chambers.'.
	self loadTogether: self script83 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/10/2010 22:34'!
update12087
	"self new update12087"
	self withUpdateLog: '- Issue 2573:	Make it possible to run cleanup non-interactively. Thanks Andreas Raab and German Arduino.
	
- Issue 2756:	Morphic Cleansing - Remove use of findA:. Thanks Guillermo Polito.

- Package name test. Thanks Luc Fabresse.'.
	self loadTogether: self script84 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/11/2010 12:50'!
update12088
	"self new update12088"
	self withUpdateLog: '- Issue 2683:	new slice package should get inbox by default as repository. Thanks Carlo Teixeira
	
- Issue 2754:	DateAndTime instance creation from a string or stream sets offset to 0. Thanks Sean De Nigris.
- DateAndTime instance creation from strings and streams default to local offset if none is specified (e.g. via class >>readFrom: and class>>fromString:). 

- DateAndTime tests updated
	- testReadFromSecond renamed to testPrintStringSecond
	- added tests for the default offset condition described above
	- added test of class>>fromString:
	
- Issue 2782:	Monticello UI does not make newly added slice or package the selected package. Thanks Carlo Teixeira
	
- Issue 2783:	Bitmap>>compressGZip unused.
	
-  Issue 2784:	More uppercase menues for file service menues.  Grogeous and dead simple but needed. Thanks Torsten Bergmann. '.
	self loadTogether: self script85 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/14/2010 23:12'!
update12089
	"self new update12089"
	self withUpdateLog: 'Issue 2798:	Replace Set class>>rehashAllSets with HashedCollection class>>rehashAllSubInstances	
Issue 2796:	Preference cleanup 1: remove 50 unsent methods
Issue 2795:	Remove some unused variables
Issue 2789:	Nuke TestRunner>>hasHistory
Issue 2800:	remove MethodContext>>#freeNames
Issue 2785:	File list menu should have grouped items	'.
	self loadTogether: self script86 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/15/2010 11:10'!
update12090
	"self new update12090"
	self withUpdateLog: 'Issue 2656:	Fix MessageNames for references to non-selectors.
Issue 2674:	Slider should be moved to Morphic-Widgets
Issue 2801:	Add standard deviation to Collections math methods
Issue 2572:	asCamelCase

'.
	self loadTogether: self script87 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/15/2010 13:16'!
update12091
	"self new update12091"
	self withUpdateLog: 'Issue 2791:	Diff browser lost menu item "Install incoming version"
Issue 2802:	Preferences Clean 2'.
	self loadTogether: self script88 merge: false.
	"Preferences removeObsolete."
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/15/2010 13:42'!
update12092
	"self new update12092"
	self withUpdateLog: 'Issue 2803:	Final Preference Clean
'.
	self loadTogether: self script89 merge: false.
	ScriptLoader new cleanUpForRelease.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/15/2010 19:18'!
update12093
	"self new update12093"
	self withUpdateLog: 'Issue 2807:	Small cleanup for Inspector
Issue 2806:	small code-critique cleanup of FileList
Issue 2799:	Class binding'.
	self loadTogether: self script90 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/16/2010 09:12'!
update12094
	"self new update12094"
	self withUpdateLog: 'Issue 2809:	Some trivial cleanup for Browser and related classes
Issue 2808:	improved isAbstractClass
Issue 1619:	Error when using decompress in the file list on a mac zip file
Issue 2797:	MIMEDocument class >> #guessTypeFromName: results in MNU (added the test)'.
	self loadTogether: self script91 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/16/2010 15:32'!
update12095
	"self new update12095"
	self withUpdateLog: 'Issue 2526:	Add Save Button to Monticello Repository View
Issue 2618:	a bit faster DependentsArray >> #select:
Issue 2513:	NewTextMorph does not accept on cmd-s.
Issue 2811:	Environment in Trait>>copy
'.
	self loadTogether: self script92 merge: false.
	TextEditor initialize.
SmalltalkEditor initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'stephaneducasse 8/16/2010 23:24'!
update12096
	"self new update12096"
	self withUpdateLog: '- Add Preferences empty class else I have to manually create before merging. This way we can merge and worked to turn the preference in setting. 

- Issue 1921:	Class>>Binding Fix. Thanks Andreas Raab. Guillermo Polito. I integrated it with the previous change I did.
	'.
	self loadTogether: self script93 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/17/2010 20:12'!
update12097
	"self new update12097"
	self withUpdateLog: '- Issue 2814:	Mods for Sugar theme support and (pluggable) label getter. Thanks Gary Chambers and Hilaire Fernandes
	
- Issue 2821:	Fixes for DropListMorph/EditableDropListMorph. Thanks Gary Chambers.'.
	self loadTogether: self script94 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/18/2010 11:42'!
update12098
	"self new update12098"
	self withUpdateLog: 'Issue 2826:	add empty PluggableButtonMorphPlus
Issue 2824:	PluggableTextMorphWithModel is not used
Issue 2333:	MCSnapshotBrowser>>allClassNames would incorrectly list the classe'.
	self loadTogether: self script95 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/19/2010 11:24'!
update12099
	"self new update12099"
	self withUpdateLog: '- Removed possiblyChanged sent but not implemented methods in NewEditor. Issue 2827:	remove all the senders of possiblyChanged

- Issue 2829:	Improve Watery2 theme drop list appearance. Thanks Gary Chambers.'.
	self loadTogether: self script96 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/19/2010 22:42'!
update12100
	"self new update12100"
	self withUpdateLog: '- Enter back to accept TextEntryDialogWindow. Thanks Gary Chambers.

- Issue 2833:	Pharo 1.1 final has two senders of #haltOnce
	
- fixes some Smalltalk -> Smalltalk globals'.
	self loadTogether: self script97 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/20/2010 11:55'!
update12101
	"self new update12101"
	self withUpdateLog: 'Issue 2835:	remove dead code from MorphicModel
Issue 2837:	Trivial code-critique cleanup of CodeLoader and related
Issue 2836:	remove ColorPatchCanvas and some other etoy related code'.
	self loadTogether: self script98 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/20/2010 22:32'!
update12102
	"self new update12102"
	self withUpdateLog: '- Issue 2810:	Missing "Software update" menu in releases confusing new users
	
- Issue 2812:	Add ISO-8859-15 and CP-1252 encodings support. Thanks Philipp Marshall.'.
	self loadTogether: self script99 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/21/2010 22:11'!
update12103
	"self new update12103"
	self withUpdateLog: '- Issue 2839:	ContextInspector. Thanks Andreas Raab
- Issue 2840:	UUID class>>fromString36:. Thanks Nicolas Cellier.
	http://bugs.squeak.org/view.php?id=7262'.
	self loadTogether: self script100 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/21/2010 23:07'!
update12104
	"self new update12104"
	self withUpdateLog: '- Cleaning left over of at: 4 and first in HTTPServerDirectory and ServerDirectory.
- Introduction of SocketPrimitiveFailed from CUIS.'.
	self loadTogether: self script101 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/22/2010 21:12'!
update12105
	"self new update12105"
	self withUpdateLog: '- Issue 2844:	String>>#numArgs is broken
	- reformat String class>>#initialize so that the initializer gets executed (no other changes there)
	- fixed String>>#tokenish and String>>#numArgs
	- 4 new tests
	Thanks Lukas Renngli
		
-  Issue 2767:	SocketStream>>upTo: and #upToAll: to fix an infinite loop. Thanks Andreas Raab'.
	self loadTogether: self script102 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/22/2010 21:43'!
update12106
	"self new update12106"
	self withUpdateLog: '- Issue 2843:	ColoredCodeStream not used. Thanks Marcus Denker.
	
- Issue 2769:	Fixes for broken SocketStream behavior. Thanks Andreas Raab'.
	self loadTogether: self script103 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/22/2010 22:24'!
update12107
	"self new update12107"
	self withUpdateLog: '-  Issue 2846:	remove empty DeprecatedPreferences Package.
-  Issue 2838:	should remove multilingual package.
'.
	self loadTogether: self script104 merge: false.
	(MCPackage named: 'Multilingual') workingCopy unregister.
(MCPackage named: 'DeprecatedPreferences') workingCopy unregister.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/23/2010 19:41'!
update12108
	"self new update12108"
	self withUpdateLog: '- Issue 2653:	Editor cursor fix. Thanks Fernando Olivero and Chris Muller.
-  Issue 1400:	Make Question Dialog more usable. Thanks Gary Chambers
- Issue 2849:	Improve About Dialog (and possibly provide new AlphaImageMorph defaultImage). Thanks Torsten Bergman.'.
	self loadTogether: self script105 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/24/2010 22:43'!
update12109
	"self new update12109"
	self withUpdateLog: '- Issue 2856:	Use unique URL to core from [Dev image]->World Menu->System>Software update. Thanks Sean De Nigris
-  Issue 2855:	Improve Duration method comments. Gracias Guillermo Polito.
- Integrated NullStyler. Thanks Benjamin van Ryseghem. I put it in the same package than the new text editor.'.
	self loadTogether: self script106 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/24/2010 23:00'!
update12110
	"self new update12110"
	self withUpdateLog: '- Network-Protocol fixes. Thanks SvenVanCaekenberghe
	Switched to proper use of #pathForFile.
- WebClient-Core, WebClientTests
	Thanks Andreas Raab and SvenVanCaekenberghe
'.
	self loadTogether: self script107 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/25/2010 19:30'!
update12111
	"self new update12111"
	self withUpdateLog: '- Issue 1899:	MethodDictionary improvement part one. Thanks Levente Uzonyi and Guillermo Polito. 
	
- Philipp fixes for WebClient. Thanks Philippe Marshall and Sven Van Caekenberghe.

 '.
	self loadTogether: self script108 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/25/2010 22:42'!
update12112
	"self new update12112"
	self withUpdateLog: '- Issue 1899:	MethodDictionary improvement. Part two.
	
- Issue 2560:	Convenient methods from Grease for Strings. We should get more of them. We need cool libraries.
	
- Issue 2857:	improve String to Number conversion. readFrom: now raises an error instead of silently returning 0. Thanks Guillermo Polito.'.
	self loadTogether: self script109 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/26/2010 11:31'!
update12113
	"self new update12113"
	self withUpdateLog: 'Issue 2863:	BlockClosure>>assert: is the same as in Object
Issue 2861:	tiny dead code removal, mostly Morph
Issue 2853:	Unnecessary URLArgumentList>>associationsDo
Issue 2845:	remove PluggableMultiColumnListMorphByItem and some unsent partbin related methods.'.
	self loadTogether: self script110 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/26/2010 21:03'!
update12114
	"self new update12114"
	self withUpdateLog: 'Issue 2870:	rescue alwaysShowScrollBars:
Issue 2865:	add #lines to String'.
	self loadTogether: self script111 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/27/2010 11:45'!
update12115
	"self new update12115"
	self withUpdateLog: '- Issue 2825:	[[true] whileTrue] fork cannot be interrupted. Thanks Henrik Johanssen.
- Issue 2860:	make Dictionary at:ifAbsent use ifNil:ifNotNil. Thanks Marcus Denker
-  Issue 2570:	Removed implicit conversion of DateAndTime equality-testing argument. Thanks Chris Mueller. We will have to address the isKindOf in DateAndTime>>=
- Issue 2873:	adding hasClassVarNamed: hasInstVarNamed: and cleaned the API. '.
	self loadTogether: self script112 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/27/2010 15:13'!
update12116
	"self new update12116"
	self withUpdateLog: 'merging webclient pmm 73'.
	self loadTogether: self script113 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/27/2010 16:11'!
update12117
	"self new update12117"
	self withUpdateLog: 'Mistake in deprecating removeClassVarNamed:.'.
	self loadTogether: self script114 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/31/2010 20:04'!
update12118
	"self new update12118"
	self withUpdateLog: 'Redoing from 11217
--------------------------------

- Issue 2880:	remove WebClient from pharo. Thanks Andreas Raab.
- Issue 2878:	enhance MethodDictionaryTests. Thanks Guillermo Polito. '.
	self loadTogether: self script115 merge: false.
	self unloadPackage: 'WebClient-Tests'.
self unloadPackage: 'WebClient-Core'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/1/2010 08:57'!
update12119
	"self new update12119"
	self withUpdateLog: '- Issue 2889:	fix LargeInteger printing. Thanks Levente and Nicolas Cellier.
-  Issue 2887:	Allow ifNotNil: #aSelector. Thanks Henrik Johanssen.
- Issue 2886:	StrikeFont WideString rendering. Thanks Henrik Johanssen.'.
	self loadTogether: self script116 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/1/2010 14:48'!
update12120
	"self new update12120"
	self withUpdateLog: '- Issue 2898:	DurationTest>>testNormalizeNanoSeconds and fix. David T. Lewis
	
- Issue 2892:	ifNotNil decompilation. Thanks Henrik Johanssen and Eliot Miranda.
	
- Issue 2895:	urlClassForScheme	 handles HTTPS. Thanks Andreas Raab. '.
	self loadTogether: self script117 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/1/2010 17:22'!
update12121
	"self new update12121"
	self withUpdateLog: '- Issue 2900:	Fix chooseVar deprecated methods in browser and other.... '.
	self loadTogether: self script118 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/3/2010 13:41'!
update12122
	"self new update12122"
	self withUpdateLog: '- 2904 HelpSystemAPIBuilderFailsOnTraits. Thanks Laurent Laffont.'.
	self loadTogether: self script119 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/3/2010 21:44'!
update12123
	"self new update12123"
	self withUpdateLog: '- Issue 2890:	Some isNil ifTrueifFalse -> ifNil:. Thanks Guillermo Polito.
- Issue 2907:	undeprecate Smalltalk os so that we can write 
	Smalltalk os versionName and Smalltalk os platformName
- Issue 2896:	Make sure system notifications for Smalltalk are up-to-date. Thanks Eliot Miranda and Adrian Leinhard.
- Issue 2893:	Network bugs. Thanks Andreas Raab.'.
	self loadTogether: self script120 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/4/2010 13:39'!
update12124
	"self new update12124"
	self withUpdateLog: '-  Issue 2910:	Should include Updater.
-  Issue 2891:	Some other ifNil instead of isNil iftrue: . Thanks Guillermo Polito and Nicolas Cellier.'.
	self loadTogether: self script121 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/8/2010 19:18'!
update12125
	"self new update12125"
	self withUpdateLog: '- Issue 2778:	Replace ParagraphEditor by TextEditor and SmalltalkEditor. Thanks Guillermo Polito.'.
	self loadTogether: self script122 merge: false.
	SmalltalkEditor initialize.
TextEditor initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/8/2010 21:31'!
update12126
	"self new update12126"
	self withUpdateLog: '- Issue 2918: Category inconsistency in ClassDescription. Thanks Nicolas Paez.
- Issue 2882: recategorize Magnitude>> max: min:,.... Thanks Jaayer
- Issue 2877: remove all methods that are equally defined in superclass. Thanks Marcus Denker.
- Issue 2909: BehaviorTest is dependent on Morphic. Thanks Pavel Krivanek.
- Issue 2884: TComparable. Thanks Jaayer'.
	self loadTogether: self script123 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/9/2010 10:55'!
update12127
	"self new update12127"
	self withUpdateLog: '- 2920 and 2921: Some little recategorizations with Gabriela Arevalo, Gabriel Barbuto, Nicolas Paez and Martin Dias.'.
	self loadTogether: self script124 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/9/2010 11:39'!
update12128
	"self new update12128"
	self withUpdateLog: '- Issue 2888:	floating point printing is wrong. Thanks Paolo Bonzini and Nicolas Cellier.
	Now 0.3-0.2 prints 0.09999999999999998 

- Issue 2919:	SystemNavigation package support. Thanks Eliot Miranda.
'.
	self loadTogether: self script125 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/9/2010 14:58'!
update12129
	"self new update12129"
	self withUpdateLog: '- Fix suffixOf:
- Issue 2107: Using test to encode package dependency structure.'.
	self loadTogether: self script126 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/9/2010 15:16'!
update12130
	"self new update12130"
	self withUpdateLog: 'Issue 2915:	remove tinyDisplay check and code
Issue 2916:	Clean MorphExtension more
Issue 2917:	CatchAll entry for small cleanups
Issue 2913:	Remove empty WebClient class categories'.
	self loadTogether: self script127 merge: false.
	SystemOrganization removeCategory: 'WebClient-Tests'.
SystemOrganization removeCategory: 'WebClient-Core'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/9/2010 21:22'!
update12131
	"self new update12131"
	self withUpdateLog: '- Issue 2936: DateAndTimeTest has failures. Thanks Pavel Krivanek.
- Issue 2937: TimespanTest >> testEnd failing. Thanks Pavel Krivanek.
- Issue 2929: remove #tiny, #tinyDisplay and the class var Tiny.
- Issue 2499:	MaskedTextMorph class for masked input fields. Thanks Dionisiygod.	'.
	self loadTogether: self script128 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/10/2010 14:35'!
update12132
	"self new update12132"
	self withUpdateLog: '- Issue 2939:	pressing ) raise an error with the new smalltalkeditor.
	
'.
	self loadTogether: self script129 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/10/2010 14:49'!
update12133
	"self new update12133"
	self withUpdateLog: 'Issue 2551:	 Performance degradation of WeakRegistry. Thanks Henrik Johanssen'.
	self loadTogether: self script130 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/10/2010 17:03'!
update12134
	"self new update12134"
	self withUpdateLog: 'Deleting Graphics package which is overlapping'.
	self loadTogether: self script131 merge: false.
	self deletePackage: 'Graphics'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/10/2010 18:20'!
update12135
	"self new update12135"
	self withUpdateLog: 'Adding some test on Zip but just for checking that the update stream is still working.'.
	self loadTogether: self script132 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/11/2010 17:56'!
update12136
	"self new update12136"
	self withUpdateLog: 'Issue 2862:	Cleanup related to retractable changesets (part1)'.
	self loadTogether: self script133 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/11/2010 18:10'!
update12137
	"self new update12137"
	self withUpdateLog: 'Issue 2862:	Cleanup related to retractable changesets (part2)'.
	self loadTogether: self script134 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/12/2010 10:43'!
update12138
	"self new update12138"
	self withUpdateLog: 'Issue 2948:	Removing code annotation from source code
Issue 2944:	fix for systemtemdictionary
Issue 2930:	Modifiable World menu
'.
	self loadTogether: self script135 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/12/2010 15:21'!
update12139
	"self new update12139"
	self withUpdateLog: 'Issue 2953:	Fixing bug with select in paragraphEditor
Issue 2956:	remvove #bigDisplay and collapsewinInPlace
Issue 2950:	ChangeList errors
Issue 2954:	Accepting method with undefined variable'.
	self loadTogether: self script136 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/12/2010 18:00'!
update12140
	"self new update12140"
	self withUpdateLog: 'Issue 2735:	Null Styler for PluggableTextMorph
Issue 2960:	Fix size for the OverRowMorph in the Browser'.
	self loadTogether: self script137 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/13/2010 14:14'!
update12141
	"self new update12141"
	self withUpdateLog: '- Issue 2955:	some settings simplification + fixes. Thanks Alain Plantec'.
	self loadTogether: self script138 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/15/2010 15:46'!
update12142
	"self new update12142"
	World setProperty: #commandKeySelectors toValue: World initializeDesktopCommandKeySelectors.
	self withUpdateLog: '- Issue 2964:	Hitting ALT+O gives DNU'.
	self loadTogether: self script139 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/18/2010 22:00'!
update12143
	"self new update12143"
	self withUpdateLog: '- Issue 2973:	PluggableTextMorph styler is not initialized. Thanks Benjamin Van Ryseghem.
- Issue 2976:	introduced SequenceableCollection >> #indexOf:startingAt:.	
- Issue 2974:	ByteArray indexOf:startingAt:
- Issue 2972:	cleaner bench printout.
- Issue 2970:	DateAndTimeTests.
- Issue 2967:	DoIt on a workspace doesnt work, raises a subscript out of bounds error. Thanks fernando.'.
	self loadTogether: self script140 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/23/2010 14:29'!
update12144
	"self new update12144"
	self withUpdateLog: '- Issue 2988:	PharoKernel Part 12'.
	self loadTogether: self script141 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/24/2010 21:13'!
update12145
	"self new update12145"
	self withUpdateLog: '- Issue 2579:	Necessary Image Changes For Cog To Work. Thanks Henrik Johanssen.
- Issue 2989:	PharoKernel Part 13. Thanks Pavel Krivanek and Nicolas Paez.'.
	self loadTogether: self script142 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/24/2010 22:08'!
update12146
	"self new update12146"
	self withUpdateLog: 'Issue 2990:	PharoKernel Part 14. Thanks Pavel Krivanek and Nicolas Paez.'.
	self loadTogether: self script143 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/27/2010 15:37'!
update12147
	"self new update12147"
	self withUpdateLog: 'Issue 2965:	Spelling mistake in font settings
Issue 3004:	Object>>Copy comment
Issue 2997:	Scriptloader cleanUpForRelease makes use of deprecated rehashAllSubInstances
Issue 2983:	ThemeSettings>>#menuSelectionColor: should return self
Issue 2978:	HelpBrowser refresh button do nothing'.
	self loadTogether: self script144 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'stephaneDucasse 9/28/2010 11:40'!
update12148
	"self new update12148"
	self withUpdateLog: '- Issue 2991:	PharoKernel Part 15 part 1.
	'.
	self loadTogether: self script145 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/28/2010 12:07'!
update12149
	"self new update12149"
	self withUpdateLog: '- Issue 2991:	PharoKernel Part 15 part 2.
	'.
	self loadTogether: self script146 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/28/2010 14:21'!
update12150
	"self new update12150"
	self withUpdateLog: '-  Issue 2991:	PharoKernel Part 15. Part 3'.
	self loadTogether: self script147 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/28/2010 14:37'!
update12151
	"self new update12151"
	self withUpdateLog: '- Issue 3007:	user of generate: in debugit code
- Issue 3008:	Delete Graphics working copy'.
	self loadTogether: self script148 merge: false.
	self deletePackage: 'Graphics'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/28/2010 21:12'!
update12152
	"self new update12152"
	self withUpdateLog: 'Issue 3000:	StandardFileStream >> recategorization of browser plugin supporting methods
Issue 2952:	Shift-selection in new TextEditor
Issue 2947:	SmalltalkEditor doent handle ESC key
Issue 2553:	SystemVersion lost its state in 1.2'.
	self loadTogether: self script149 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/29/2010 09:27'!
update12153
	"self new update12153"
	self withUpdateLog: 'Issue 3014:	Use pragmas to make primitives extensible
Issue 3013:	SystemVersion deprecate #version:'.
	self loadTogether: self script150 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/29/2010 13:49'!
update12154
	"self new update12154"
	self withUpdateLog: 'Issue 2779:	Should fix fileout after 2661
Issue 2161:	getRecentLocatorWithPrompt: fully duplicated in ChangeLIst and ChangeSet
Issue 2823:	Leap year handling in compression
Issue 2969:	zipping a directory
Issue 2957:	Removal AcornFileDirectory and RiscOS Plattform'.
	self loadTogether: self script151 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/30/2010 11:17'!
update12155
	"self new update12155"
	self withUpdateLog: '- Issue 2991:	PharoKernel Part 15. Part 4
- Issue 2992:	PharoKernel Part 16'.
	self loadTogether: self script152 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/30/2010 11:36'!
update12156
	"self new update12156"
	self withUpdateLog: ' - Issue 2993:	PharoKernel Part 17'.
	self loadTogether: self script153 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/30/2010 12:35'!
update12157
	"self new update12157"
	self withUpdateLog: '- Issue 3019:	add instance side methods to PackageInfo and SystemOrganizer. 
-  Issue 2995:	PharoKernel Part 19.'.
	self loadTogether: self script154 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 9/30/2010 13:22'!
update12158
	"self new update12158"
	self withUpdateLog: '- Issue 2996:	Base64MimeConverter with multiline option. Thanks dik :)'.
	self loadTogether: self script155 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 9/30/2010 14:02'!
update12159
	"self new update12159"
	self withUpdateLog: 'Issue 3018:	DisplayScreen is missing Tiny class variable
Issue 3017:	UpdateStreamer is missing saveLocally instance variable
Issue 3016:	ParseNodeEnumerator is missing theSelectBlock instance variable
Issue 2813:	MailSender is not deployable'.
	self loadTogether: self script156 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/1/2010 10:04'!
update12160
	"self new update12160"
	self withUpdateLog: 'Issue 3022:	Custom help books should be able to define where subbooks should be placed/displayed
Issue 2980:	dropping a text file into the host window raises an error
'.
	self loadTogether: self script157 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/1/2010 16:07'!
update12161
	"self new update12161"
	self withUpdateLog: '- Issue 3003: handleDisabledKey: is missing in Editor and subclasses
- Issue 2963: systemOrganizer fixes. Thanks German Leiva and James Foester'.
	self loadTogether: self script158 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/1/2010 16:16'!
update12162
	"self new update12162"
	self withUpdateLog: 'Issue 2713:	Changelist deserves some fixes
Issue 3030:	Remove Explain... code (again)
Issue 3023:	change the initial windows position strategy
Issue 3028:	PluggableListMorphByItem >> getCurrentSelectionIndex access directly a non-initailized instance variable'.
	self loadTogether: self script159 merge: false.
	RealEstateAgent usedStrategy: #cascadeFor:initialExtent:world:.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/1/2010 16:43'!
update12163
	"self new update12163"
	self withUpdateLog: '- Issue 3035:	Workspace(Object)>>doesNotUnderstand: #spawn:. Thanks mariano Martinez-Peck
- Issue 3032:	Memory consuption of Objects. Thanks mariano Martinez-Peck
- Issue 3037:	SpaceTally should use #instancesSizeInMemory. Thanks mariano Martinez-Peck'.
	self loadTogether: self script160 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/1/2010 17:06'!
update12164
	"self new update12164"
	self withUpdateLog: '- Issue 3040:	Launch change sorter in Pharo 12162 throws DNU. Thanks Luc Fabresse.
-  Issue 3020:	Monticello uses a lot of Smalltalk instead of Smalltalk globals. Thanks Nicolas Paez'.
	self loadTogether: self script161 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/1/2010 17:27'!
update12165
	"self new update12165"
	self withUpdateLog: '-  Issue 3010:	Create button of debugger does not appear when doing step into and step over. Thanks Hernan Wilkinson and Luc Fabresse and Jean-Baptiste Arnaud.
- Issue 3011:	Create button fails when the doesNotUnderstand: context is not selected. Thanks Hernan Wilkinson and Luc Fabresse and Jean-Baptiste Arnaud.
- Issue 965:	Messages send but not implemented.'.
	self loadTogether: self script162 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/1/2010 17:53'!
update12166
	"self new update12166"
	self withUpdateLog: 'Issue 2943:	SUnit 4. Thanks Jannik Laval and Nicolas Anquetil'.
	self loadTogether: self script163 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/2/2010 18:17'!
update12167
	"self new update12167"
	self withUpdateLog: '-  Issue 3036:  SUnit Refactoring (introduced class factory). Thanks Thanks Sean De Nigris.
- Issue 3047: Added intention revealing helper method to AppRegistry class>>register:. Thanks Sean De Nigris.
- Issue 3055:	postCopy in StrikeFontSet. Thanks Nicolas Cellier.
- Issue 3056:	EventManager uses postCopy. Thanks Nicolas Cellier.
- Issue 3054:	Heap improvements. Thanks Nicolas Cellier.
- Issue 3053:	Better showMenu. Thanks Tobias Pape.'.
	self loadTogether: self script164 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/3/2010 15:21'!
update12168
	"self new update12168"
	self withUpdateLog: '- Issue 3043:	 Refactor SystemOrganizer to decouple it from Smalltalk. Thanks Nicolas Paez and Damien Pollet.
- Issue 3027:	Base64MimeConverterTest>>#testOnByteArray raise an error. Thanks Cyrille Delaunay'.
	self loadTogether: self script165 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/4/2010 19:38'!
update12169
	"self new update12169"
	self withUpdateLog: '- fixing showMenus. Thanks Gary Chambers'.
	self loadTogether: self script166 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/5/2010 11:38'!
update12170
	"self new update12170"
	self withUpdateLog: '- Issue 3060:	Update Monticello to detect method recategorization correctly. Thanks Pavel Krivanek and Henrik Johanssen'.
	self loadTogether: self script167 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/5/2010 12:08'!
update12171
	"self new update12171"
	self withUpdateLog: '- Issue 3060:	Update Monticello to detect method recategorization correctly. post fix.'.
	self loadTogether: self script168 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/5/2010 18:36'!
update12172
	"self new update12172"
	self withUpdateLog: '- Issue 2902:	CodeMorph removal. Thanks Fernando Oliviero
- Issue 3060:	Update Monticello to detect method recategorization correctly. Final fix :)'.
	self loadTogether: self script169 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/7/2010 13:59'!
update12185
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/7/2010 14:10'!
update12186
	"self new update12186"
	self withUpdateLog: 'Issue 3071:	fixing timestamp tests
Issue 3068:	Non portable SmalltalkImage>>platformName deprecationWarning
Issue 3063:	removing explain
Issue 3039:	There should not be any configuration on Core'.
	self loadTogether: self script170 merge: false.
	(MCPackage named: 'ConfigurationOfGofer') unload.
(MCPackage named: 'ConfigurationOfOmniBrowser') unload.
(MCPackage named: 'ConfigurationOfMetacello') unload.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/9/2010 08:33'!
update12187
	"self new update12187"
	self withUpdateLog: '- Issue 2883:	Anymorphic Style- Some parts of it. Does not work. 
- Issue 2947:	SmalltalkEditor does not handle ESC key. Thanks Fernando Olivero.'.
	self loadTogether: self script171 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/11/2010 09:44'!
update12188
	"self new update12188"
	self withUpdateLog: '- Issue 3086:	MCMethodDefinition>>shutdown hack to avoid lock down.
- Issue 2875:	PharoKernel Part 11. Thanks Pavel Krivanek and Nicolas Paes
'.
	self loadTogether: self script172 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/11/2010 15:19'!
update12189
	"self new update12189"
	self withUpdateLog: '- Issue 2883:	Anymorphic Style. Thanks Anymorphic and Nicolas Paez.
- Issue 2979:	Controlling UI feedback. BlockClosure>>silentlyValue'.
	self loadTogether: self script173 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/11/2010 16:34'!
update12190
	"self new update12190"
	self withUpdateLog: '- Issue 3065:	HardCoded SystemOrganization references.
'.
	self loadTogether: self script174 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/11/2010 17:01'!
update12191
	"self new update12191"
	self withUpdateLog: '- Issue 3092:	Additional test for weak registry to check for deadlocks. Thanks Igor Stasenko.
Issue 3093:	Weaklings cleanup & fixes. Thanks Igor Stasenko.'.
	self loadTogether: self script175 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/12/2010 13:14'!
update12192
	"self new update12192"
	self withUpdateLog: '- Issue 2883: UITheme Pro.
- Issue 3072: System error handling fail on changing Integer>>+. Thanks johan fabry.'.
	self loadTogether: self script176 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/12/2010 22:24'!
update12193
	"self new update12193"
	self withUpdateLog: '- Issue 3096:	FreeType problem with new finalization. Thanks Igor Stasenko.
-  Issue 2999:	Object>>isConflict. Moving isConflict from Object to MCPacthOperation. 
-  Issue 3085:	StringHolder should not be in Kernel'.
	self loadTogether: self script177 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/12/2010 23:13'!
update12194
	"self new update12194"
	self withUpdateLog: '- Issue 3098:	BUG+Fix annotation panes stop working again.'.
	self loadTogether: self script178 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/17/2010 20:55'!
update12195
	"self new update12195"
	self withUpdateLog: '- Issue 3113:	TextEditor autoEnclose settings. Thanks Pavel Krivanek.
	
- Issue 3110:	ProjectLauncher readDocumentAtStartup needs a setting. Thanks Pavel Krivanek.
	
-  Issue 3103:	better Morphic detection in AutoStart startUp:. Thanks Pavel Krivanek.
	
- Issue 3102:	removeAllButPackages: hackish method. Thanks Pavel Krivanek.'.
	self loadTogether: self script179 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/18/2010 14:58'!
update12196
	"self new update12196"
	self withUpdateLog: '- Issue 3121:	LongTest API improvement. 
- Issue 3120:	MultiByteFileStream class>>lineEndDefault.
- Issue 3119:	rounded and truncated for DateAndTime.
- Issue 3126:	Cleans do: symbol usage'.
	self loadTogether: self script180 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/19/2010 14:07'!
update12197
	"self new update12197"
	self withUpdateLog: '- Issue 3127:	Missing Close in About Dialog. Thanks Alain Plantec.
- Issue 3125:	SharedQueue/Monitor cleans. Thanks levente. '.
	self loadTogether: self script181 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/19/2010 14:37'!
update12198
	"self new update12198"
	self withUpdateLog: 'initialize LongTestCase correctly'.
	self loadTogether: self script182 merge: false.
	LongTestCase initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/19/2010 14:52'!
update12199
	"self new update12199"
	self withUpdateLog: '- Issue 3048:	MC method cache fix. Thanks Igor Stasenko'.
	self loadTogether: self script183 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/19/2010 21:53'!
update12200
	"self new update12200"
	self withUpdateLog: '- Issue 2653:	Editor cursor fix: remove autoclose in texteditor.
	
- Issue 3128:	AuthorRequestImprovement. Thanks Alain Plantec
	
- Issue 3099:	Create method in the debugger does not provides getter/setters implementors. Thanks Hernan Wilkinson.'.
	self loadTogether: self script184 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/20/2010 22:37'!
update12201
	"self new update12201"
	self withUpdateLog: '- Issue 1800:	MenuIcons and ThemeIcons should be merged. Big thanks to alain plantec!!!!!!'.
	self loadTogether: self script185 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/20/2010 22:52'!
update12202
	"self new update12202"
	self withUpdateLog: '- Issue 3070:	weird replacements in TextEditor. Thanks Alain Plantec!!!!!!'.
	self loadTogether: self script186 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/21/2010 11:48'!
update12203
	"self new update12203"
	self withUpdateLog: '- Issue 654:	inconsistent highlight color. Thanks Alain Plantec
- Issue 3101: Wrong Monticello packages initialization order. Thanks Pavel Krivanek'.
	self loadTogether: self script187 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/23/2010 12:09'!
update12204
	"self new update12204"
	self withUpdateLog: 'Issue 2868:	allClassesUsingPool: allClassesUsingPoolVariable: for systemNavigation
Issue 3046:	BUG: LineMorph class>>from:to:color:width: returns a PolygonMorph
Issue 3130:	MethodReference >> #isLocalSelector should not be part of Monticello package
Issue 3095:	Character isLiteral is in wrong category
Issue 3134:	Cleaning uniclasses from smartRefStream'.
	self loadTogether: self script188 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/23/2010 12:43'!
update12205
	"self new update12205"
	self withUpdateLog: 'Issue 2619:	 ignore vm parameters with nil value in MessageTally, so it can be used in Cog
Issue 1885:	Disable Scroll Wrapping in PluggableListMorph
Issue 3142:	Updater package has no repository
Issue 2876:	setStandardClass: aClass methodSymbol: methodSym (first part)'.
	self loadTogether: self script189 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/23/2010 14:28'!
update12206
	"self new update12206"
	self withUpdateLog: 'Issue 2876:	setStandardClass: aClass methodSymbol: methodSym (part2)
Issue 3116:	Reduce DecompilerTest failures to three legitimate failures.
Issue 3140:	Utilities removing'.
	self loadTogether: self script190 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/23/2010 15:17'!
update12207
	"self new update12207"
	self withUpdateLog: 'starting to clean systemNavigation and to make sure that it can work on an environment.'.
	self loadTogether: self script191 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 10/23/2010 15:47'!
update12208
	"self new update12208"
	self withUpdateLog: 'fixing implementors'.
	self loadTogether: self script192 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/23/2010 16:48'!
update12209
	"self new update12209"
	self withUpdateLog: 'Issue 3049:	ClassBuilderTest
Issue 1746:	ReferenceStream>>readOnlyFileNamed: is missing
Issue 1981:	Raising DuplicateError Exception in class builder
Issue 2525:	SystemWindow out of focus color wrong
Issue 3143:	To mark a test as an expected failure, one has to overwrite expectedFailures
'.
	self loadTogether: self script193 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/23/2010 17:12'!
update12210
	"self new update12210"
	self withUpdateLog: 'Issue 2653:	Editor cursor fix
Issue 3015:	When a test is restarted in the debugger, #tearDown and #setUp and not send
Issue 1853:	NetNameResolver localHostAddress returns public or private address instead of loopback address.'.
	self loadTogether: self script194 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/24/2010 11:30'!
update12211
	"self new update12211"
	self withUpdateLog: 'Issue 3141:	nil when writeDefinition computing
Issue 3147:	How removing a class can broke DataStream/ReferenceStream/SmartRefStream
Issue 3106:	EToys resources relict in Form >> unhibernate
Issue 3146:	UIThemeStandardSqueaksmallDebugIcon is calling itself
Issue 2525:	SystemWindow out of focus color wrong
Issue 1766:	#objectForDataStream: should be in Package System-Serialization'.
	self loadTogether: self script195 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/24/2010 16:44'!
update12212
	"self new update12212"
	self withUpdateLog: 'Issue 3137:	Comment in Behavior >> allMethods is wrong
Issue 3149:	No setting in the setting browser
Issue 3150:	implementor of and sender of dont retrieve class side methods
Issue 2340:	Cursor for textEditor or new paragraph'.
	self loadTogether: self script196 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/24/2010 20:24'!
update12213
	"self new update12213"
	self withUpdateLog: 'Issue 3153:	MCVersionReader uses FileList registration
Issue 3152:	wrong Monticello package dependencies
Issue 1954:	Browser less hardcoded UI class
Issue 3038:	ToolBuilderTests>>testGetButtonSideEffects seems to be wrong
Issue 3033:	PharoCorePackageDependenciesTests make tests with packages not presents in pharo 1.2
Issue 2298:	RunArray which would cause Texts with empty runs to lose their emphasis.
'.
	self loadTogether: self script197 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/25/2010 10:49'!
update12214
	"self new update12214"
	self withUpdateLog: 'Issue 3156:	StandardWindow should not redefine #initialExtent
Issue 2899:	Slice creation should add dirty packages are dependent
Issue 2766:	World Screen capture should be adapted to Pharo
Issue 2256:	#sortBy: should be deprecated'.
	self loadTogether: self script198 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/25/2010 16:43'!
update12215
	"self new update12215"
	self withUpdateLog: 'Issue 3158:	Deprecate translation support protocol
Issue 3157:	Text entry dialog window badly compute minimumWidth
Issue 3025:	SystemVersionTest>>testDowngrade use a deprecated method
Issue 3029:	The Menus of the Source panes reverted to the old complex ones...
Issue 3025:	SystemVersionTest>>testDowngrade use a deprecated method'.
	self loadTogether: self script199 merge: false.
	SmalltalkEditor initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/26/2010 15:43'!
update12216
	"self new update12216"
	self withUpdateLog: 'Issue 3161:	StandardFileStream >> nextPutAll: stringOrByteArray
Issue 3163:	Fix Menu SmalltalkEditor more
Issue 3159:	TextMorph cleaning
Issue 3077:	Suggestion for Remodularisation -> Form
- put depration call into sortBy:
'.
	self loadTogether: self script200 merge: false.
	SmalltalkEditor initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/27/2010 10:20'!
update12217
	"self new update12217"
	self withUpdateLog: 'Issue 3164:	Fix find and seach all source
Issue 1801:	Rescue Sophie Undo framework
Issue 2797:	MIMEDocument class >> #guessTypeFromName: results in MNU
'.
	self loadTogether: self script201 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/28/2010 17:00'!
update12218
	"self new update12218"
	self withUpdateLog: 'Issue 3075:	Suggestion for Remodularisation -> ChangeSet
Issue 2994:	PharoKernel Part 18 (part 1)'.
	self loadTogether: self script202 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/29/2010 17:55'!
update12219
	"self new update12219"
	self withUpdateLog: 'Issue 3145:	Glamourous Theme integration
Issue 3171:	Fix an Undeclared ref in UndoRecord
Issue 3170:	Catchall for trivial cleanups
Issue 2994:	PharoKernel Part 18 (part 2)
'.
	self loadTogether: self script203 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/30/2010 17:25'!
update12220
	"self new update12220"
	self withUpdateLog: 'Issue 2387:	Workspace
Issue 2903:	EntryFieldMorph>>hasErrors: aBoolean
Issue 3174:	Cleanup packages
'.
	self loadTogether: self script204 merge: false.
	ScriptLoader new deletePackage: 'Default'.
ScriptLoader new deletePackage: 'DolphinCompatibility-ValueAdapters'.
ScriptLoader new deletePackage: 'Announcements-Slice'.
ScriptLoader new deletePackage: 'Announcements'.
ScriptLoader new deletePackage: 'Environments'.
ScriptLoader new deletePackage: 'System-Tests-ChangeNotification'.
ScriptLoader new deletePackage: 'Updater'.
ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/31/2010 09:43'!
update12221
	"self new update12221"
	self withUpdateLog: 'Issue 2815:	Must kick me to provide TEasilyThemed helpers for all widgets (first part)
Issue 3186:	UndoManagerTest needs to be moved to a test package
Issue 3176:	Move Debugger tests from Tools to ToolsTest
Issue 3175:	Remove strange Packages
'.
	self loadTogether: self script205 merge: false.
	ScriptLoader new deletePackage: 'Polymorph-Widgets-Themes-Additions'.
ScriptLoader new deletePackage: 'HashedCollectionFixes'.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/31/2010 11:37'!
update12222! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/31/2010 11:37'!
update12223! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/31/2010 11:37'!
update12224! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 10/31/2010 17:37'!
update12225
	"self new update12225"
	self withUpdateLog: 'Issue 3190:	Move Utilities to Deprecated Package. Add Preferences class for backward compatibility
Issue 3144:	updateStreamer should be verbose when it do explicitly a update
'.
	self loadTogether: self script206 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/1/2010 08:14'!
update12226
	"self new update12226"
	self withUpdateLog: '- Issue 3200:	Float do not print exactly when negative. Thanks Nicolas cellier. (I made a silly mistake).
- Issue 3178:	FractionTest>>#testDegreeCos. Thanks Nicolas cellier.'.
	self loadTogether: self script207 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/2/2010 17:36'!
update12227
	"self new update12227"
	self withUpdateLog: '- Issue 2869:	Rewrite system navigation. Thanks Luc Fabresse.
- Issue 2781:	MethodReference has been extended to have source code. Thanks Johan Brichau, Benjamin van Rysenghem and JB Arnaud.'.
	self loadTogether: self script208 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/2/2010 18:08'!
update12228
	"self new update12228"
	self withUpdateLog: '- Issue 3173:	TestCase>>#expectedFailures far too slow when running huge Testsuites. Reverted to expected failures previous implementation.'.
	self loadTogether: self script209 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 11/4/2010 13:50'!
update12229
	"self new update12229"
	self withUpdateLog: 'Issue 3204:	something is wrong [...] with the collapse (minimize)
Issue 3199:	isWords correct comment
Issue 3195:	Bitmap tests
Issue 3202:	references in System->Settings should refer to action click menu instead of yellow button menu	
'.
	self loadTogether: self script210 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/8/2010 18:53'!
update12230
	"self new update12230"
	self withUpdateLog: '- Issue 3212:	Remove Transcript show in methodReference access. Thanks Benjamin v. Ryseghem.
- Issue 3209:	InputEventFetcher>>primGetNextEvent: does not set array at: 1 put: EventTypeNone. on failing primitive. Thanks Stefan Marr and Igo Stasenko.
- Issue 3193:	SystemNavigation unusedBlocks. Thanks Eliot Miranda and Luc Fabresse.'.
	self loadTogether: self script211 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/9/2010 18:56'!
update12231
	"self new update12231"
	self withUpdateLog: '- Issue 3222:	saveSession should return its resuming state'.
	self loadTogether: self script212 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/11/2010 12:43'!
update12232
	"self new update12232"
	self withUpdateLog: '- Issue 3223:	Replace all sends to compile: in SystemNavigationTest by compileSilently:. Thanks Luc Fabresse.
	
-  Issue 3220:	SystemNavigation: Better System. Thanks Benjamin van Ryseghem.
	
- Issue 3218:	shortImageName	
	'.
	self loadTogether: self script213 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/11/2010 12:59'!
update12233
	"self new update12233"
	self withUpdateLog: '- Issue 3219:	Brand new Finder. Thanks Benjamin. 
	This looks really cool.'.
	self loadTogether: self script214 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/11/2010 22:42'!
update12234
	"self new update12234"
	self withUpdateLog: '- Issue 3244:	Correct the confusion radiansToDegrees/degreesToRadians. Thanks Nicolas Cellier
- Issue 3239:	CUIS added MessageTally default size tweaks
- Issue 3229:	More robust MCFileRepositoryInspector. Thanks Levente.
- Issue 3221:	New Class queries for variables (class and pool). Thanks Benjamin.'.
	self loadTogether: self script215 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/11/2010 23:11'!
update12235
	"self new update12235"
	self withUpdateLog: '-  Issue 3088:	MNU Text>>withBlanksTrimmed. Thanks Guillermo Polito.
-  Issue 3216:	[enh] Support for Metacello in Monticello. Thanks Dale and Alexandre.'.
	self loadTogether: self script216 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/13/2010 17:27'!
update12236
	"self new update12236"
	self withUpdateLog: '- Issue 3185:	BitmapStreamTests have errors.
- Issue 3249:	SourceReference throw an error when <historical> is answered. 
- Issue 3226:	New finder enh. Thanks Benjamin van Ryseghem.
- Issue 3182:	UndoManagerTest>>#testGrouping failing. Thanks Andy Kellens.'.
	self loadTogether: self script217 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'HasBinding 11/13/2010 18:09'!
update12237
	"self new update12237"
	self withUpdateLog: '- Issue 3087:	optimize hasBindingThatBeginsWith:. Tx Levente, Mariano and Guillermo.'.
	self loadTogether: self script218 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/13/2010 21:10'!
update12238
	"self new update12238"
	self withUpdateLog: '- Update Regex to sync with latest version of lukas. http://source.lukas-renggli.ch/unsorted/ 
now up to 40'.
	self loadTogether: self script219 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/13/2010 23:00'!
update12239
	"self new update12239"
	self withUpdateLog: '- Issue 2793:	Compiler fixes. Thanks Eliot Miranda.
- Issue 2771:	should add PharoTreatedInbox to the list of repositories. '.
	self loadTogether: self script221 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/14/2010 23:10'!
update12240
	"self new update12240"
	self withUpdateLog: '- Issue 2436:	Compiler outofScopeNotification. Thanks Eliot Miranda.
- Issue 3259:	Eliot Compiler Fixes Part one. Thanks Eliot Miranda.
- Issue 3261:	Fix select unchanged definitions for variableSubclass: class defs. Thanks Eliot Miranda.
- Issue 3253:	Announcer. Extraction ActionSequence creation in subscription logic. Thanks Dionsisiygod'.
	self loadTogether: self script222 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/15/2010 21:51'!
update12241
	"self new update12241"
	self withUpdateLog: '- Issue 3251:	Accept a change when editing a help text gives MNU. Thanks Torsten Bergmann.
- Issue 3252:	[Repackage] Announcements package should be well structured. Thanks Torsten Bergmann.'.
	self loadTogether: self script223 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/15/2010 22:20'!
update12242
	"self new update12242"
	self withUpdateLog: '- Issue 3210:	SimpleMorphic Integration. Part One. SMx01-PharoEnhAndPreliminaries-jmv.3.cs  contains some refactoring needed to make it possible to add another GUI to Pharo. Nothing here is specific to SimpleMorphic, and I recommend integrating them into Pharo. Juan Vuletich.'.
	self loadTogether: self script224 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/17/2010 20:39'!
update12243
	"self new update12243"
	self withUpdateLog: '- Issue 3266:	Clean TextEditor. Thanks alain plantec'.
	self loadTogether: self script225 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/17/2010 21:52'!
update12244
	"self new update12244"
	self withUpdateLog: '- Issue 3265:	SystemWindow addAll:FullFrame: with hard reference to BrowserCommentTextMorph. Thanks Alain Plantec.'.
	self loadTogether: self script226 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/18/2010 10:00'!
update12245
	"self new update12245"
	self withUpdateLog: '- Issue 3267:	MultiNewParagraphWithSelectionColor depracted. Thanks Alain Plantec
- Issue 3268:	FindReplaceService dont trap well regex input error'.
	self loadTogether: self script227 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 11/18/2010 23:02'!
update12246
	"self new update12246"
	self withUpdateLog: '- Issue 3210:	SimpleMorphic Integration. Part two and three.
	-SMx02-PharoEnhAndPreliminariesCoda.1.cs contains some refactorings needed to make it possible to add another GUI to Pharo. 
	- SMx03-ExtensionMethodsPart1.3.cs contains a few useful methods, not specific to SimpleMorphic, but optional anyway. You might integrate this into Pharo or consider it part of SimpleMorphic.'.
	self loadTogether: self script228 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:09'!
updateUpdatesList: aString
	"ScriptLoader new updateUpdatesList: 'cleanUpMethods'"
	
	| str |
	str := FileDirectory default oldFileNamed: 'updates.list'.
	[	str
			setToEnd;
			cr;
			nextPutAll: self currentUpdateVersionNumber asString;
			nextPutAll: '-Pha-', aString, '.cs' ]
		ensure: [ str close ]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'lr 3/14/2010 21:13'!
verifyNewUpdate
	self repository: self class defaultMCWaitingFolder.
	self class loadLatestPackage: 'ScriptLoader' fromRepository: self repository.
	self perform: ('update' , self getLatestUpdateNumber asString) asSymbol.
	(self confirm: 'Completed loading the new update. Run all test now?')
		ifTrue: [ 
			Author fullName: 'tester'.
			Smalltalk globals at: #TestRunner ifPresent: [ :class | class open model runAll ] ]! !

!ScriptLoader methodsFor: 'private' stamp: 'al 11/1/2008 18:19'!
waitingFolderMCZFiles
	^ self class defaultMCWaitingFolder allFileNames
		reject: [:each | each =  '.DS_Store']! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/24/2008 16:45'!
withUpdateLog: aString

	self logStream nextPutAll: ' ------------------------------------------------------' ; cr.
	self logStream nextPutAll: thisContext sender selector asString. 
	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'sd 3/24/2008 17:31'!
workingCopyFromPackageName: aString
	"self new workingCopyFromPackageName: '39Deprecated' "
	
	|pa|
	pa := MCPackage named: aString.
	^ pa workingCopy 
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 7/8/2006 18:20'!
writeCS: extensionAndNumber forUpdate: updateNumber
	"ScriptLoader new writeCS: '-sd.210' forUpdate: 7037"
	
	self writeCS: extensionAndNumber forUpdate: updateNumber withName: 'changeMe'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 2/25/2010 18:09'!
writeCS: extensionAndNumber forUpdate: updateNumber withName: aSt
	"ScriptLoader new writeCS: '-md.2929' forUpdate: 7049 withName: 'cleanUpMethods'"
	

	FileDirectory default 
		forceNewFileNamed:  updateNumber asString, 'update', aSt, '.cs'
		do: [ :stream | self generateCS: extensionAndNumber fromUpdate: updateNumber on: stream].
! !
ScriptLoader initialize!
